@@ -10,18 +10,18 @@ import portalocker
 
 from azure.cli.telemetry.util import save_payload
 
-__version__ = "1.0.8"
+__version__ = "1.1.0"
 
 DEFAULT_INSTRUMENTATION_KEY = 'c4395b75-49cc-422c-bc95-c7d51aef5d46'
 
 
-def _start(config_dir):
+def _start(config_dir, cache_dir):
     from azure.cli.telemetry.components.telemetry_logging import get_logger
 
     logger = get_logger('process')
 
-    args = [sys.executable, os.path.realpath(__file__), config_dir]
-    logger.info('Creating upload process: "%s %s %s"', *args)
+    args = [sys.executable, os.path.realpath(__file__), config_dir, cache_dir]
+    logger.info('Creating upload process: "%s %s %s %s"', *args)
 
     kwargs = {'args': args}
     if os.name == 'nt':
@@ -42,20 +42,19 @@ def _start(config_dir):
             kwargs['stdout'] = subprocess.DEVNULL
             kwargs['stderr'] = subprocess.STDOUT
 
-    subprocess.Popen(**kwargs)
-    logger.info('Return from creating process')
+    process = subprocess.Popen(**kwargs)
+    logger.info('Return from creating process %s', process.pid)
 
 
 def save(config_dir, payload):
-    from azure.cli.telemetry.util import should_upload
     from azure.cli.telemetry.components.telemetry_client import CliTelemetryClient
     from azure.cli.telemetry.components.telemetry_logging import get_logger
 
     logger = get_logger('main')
     try:
         # Split payload to cli events and extra events by instrumentation key
-        # cli events should be stored in local cache and sent together
         # extra events can be sent immediately
+        # cli events will be handled in separate process
         import json
         events = json.loads(payload)
 
@@ -75,43 +74,34 @@ def save(config_dir, payload):
         logger.info("Split cli events and extra events failure: %s", str(ex))
         cli_payload = payload
 
-    if save_payload(config_dir, cli_payload) and should_upload(config_dir):
+    cache_dir = save_payload(config_dir, cli_payload)
+    if cache_dir:
         logger.info('Begin creating telemetry upload process.')
-        _start(config_dir)
+        _start(config_dir, cache_dir)
         logger.info('Finish creating telemetry upload process.')
 
 
 def main():
-    from azure.cli.telemetry.util import should_upload
-    from azure.cli.telemetry.components.telemetry_note import TelemetryNote
     from azure.cli.telemetry.components.records_collection import RecordsCollection
     from azure.cli.telemetry.components.telemetry_client import CliTelemetryClient
     from azure.cli.telemetry.components.telemetry_logging import config_logging_for_upload, get_logger
 
     try:
         config_dir = sys.argv[1]
+        cache_dir = sys.argv[2]
         config_logging_for_upload(config_dir)
 
         logger = get_logger('main')
-        logger.info('Attempt start. Configuration directory [%s].', sys.argv[1])
-
-        if not should_upload(config_dir):
-            logger.info('Exit early. The note file indicates it is not a suitable time to upload telemetry.')
-            sys.exit(0)
+        logger.info('Attempt start. Configuration directory [%s]. Cache directory [%s].', sys.argv[1], sys.argv[2])
 
         try:
-            with TelemetryNote(config_dir) as telemetry_note:
-                telemetry_note.touch()
+            collection = RecordsCollection(cache_dir)
+            collection.snapshot_and_read()
 
-                collection = RecordsCollection(telemetry_note.get_last_sent(), config_dir)
-                collection.snapshot_and_read()
-
-                client = CliTelemetryClient()
-                for each in collection:
-                    client.add(each, flush=True)
-                client.flush(force=True)
-
-                telemetry_note.update_telemetry_note(collection.next_send)
+            client = CliTelemetryClient()
+            for each in collection:
+                client.add(each, flush=True)
+            client.flush(force=True)
         except portalocker.AlreadyLocked:
             # another upload process is running.
             logger.info('Lock out from note file under %s which means another process is running. Exit 0.', config_dir)
