@@ -12,8 +12,8 @@ from azure.cli.command_modules.keyvault._client_factory import (
     get_client, get_client_factory, Clients, is_azure_stack_profile)
 
 from azure.cli.command_modules.keyvault._transformers import (
-    extract_subresource_name, filter_out_managed_resources,
-    multi_transformers, transform_key_decryption_output, keep_max_results,
+    filter_out_managed_resources, transform_security_domain_output,
+    multi_transformers, transform_key_decryption_output, keep_max_results, transform_key_list_output,
     transform_key_output, transform_key_encryption_output, transform_key_random_output,
     transform_secret_list, transform_deleted_secret_list, transform_secret_set,
     transform_secret_set_attributes, transform_secret_show_deleted, transform_secret_delete, transform_secret_recover,
@@ -25,7 +25,8 @@ from azure.cli.command_modules.keyvault._transformers import (
 from azure.cli.command_modules.keyvault._format import transform_secret_list_table
 
 from azure.cli.command_modules.keyvault._validators import (
-    process_secret_set_namespace, validate_private_endpoint_connection_id, validate_role_assignment_args)
+    process_secret_set_namespace, validate_key_create,
+    validate_private_endpoint_connection_id, validate_role_assignment_args)
 
 
 def transform_assignment_list(result):
@@ -45,7 +46,6 @@ def load_command_table(self, _):
     mgmt_vaults_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.vaults)
     mgmt_pec_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.private_endpoint_connections)
     mgmt_plr_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.private_link_resources)
-    data_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT)
     data_key_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_KEYS)
     data_certificate_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_CERTIFICATES)
     data_secret_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_SECRETS)
@@ -53,12 +53,12 @@ def load_command_table(self, _):
     if not is_azure_stack_profile(self):
         mgmt_hsms_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.managed_hsms)
         mgmt_hsms_regions_entity = get_client(self.cli_ctx, ResourceType.MGMT_KEYVAULT, Clients.mhsm_regions)
-        private_data_entity = get_client(self.cli_ctx, ResourceType.DATA_PRIVATE_KEYVAULT)
+        data_security_domain_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_SECURITY_DOMAIN)
         data_backup_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_BACKUP)
         data_access_control_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_ACCESS_CONTROL)
         data_setting_entity = get_client(self.cli_ctx, ResourceType.DATA_KEYVAULT_ADMINISTRATION_SETTING)
     else:
-        mgmt_hsms_entity = mgmt_hsms_regions_entity = private_data_entity = data_backup_entity = \
+        mgmt_hsms_entity = mgmt_hsms_regions_entity = data_security_domain_entity = data_backup_entity = \
             data_access_control_entity = data_setting_entity = None
 
     kv_vaults_custom = CliCommandType(
@@ -77,25 +77,19 @@ def load_command_table(self, _):
     # Management Plane Commands
     with self.command_group('keyvault', mgmt_vaults_entity.command_type,
                             client_factory=mgmt_vaults_entity.client_factory) as g:
-        g.custom_command('create', 'create_vault_or_hsm', supports_no_wait=True,
-                         doc_string_source=mgmt_vaults_entity.models_docs_tmpl.format('VaultProperties'))
+        g.custom_command('create', 'create_vault_or_hsm', supports_no_wait=True)
         g.custom_command('recover', 'recover_vault_or_hsm', supports_no_wait=True)
         g.custom_command('list', 'list_vault_or_hsm')
-        g.custom_show_command('show', 'get_vault_or_hsm',
-                              doc_string_source=mgmt_vaults_entity.operations_docs_tmpl.format('get'))
-        g.custom_command('delete', 'delete_vault_or_hsm', supports_no_wait=True,
-                         doc_string_source=mgmt_vaults_entity.operations_docs_tmpl.format('delete'))
-        g.custom_command('purge', 'purge_vault_or_hsm', supports_no_wait=True,
-                         doc_string_source=mgmt_vaults_entity.operations_docs_tmpl.format('begin_purge_deleted'))
+        g.custom_show_command('show', 'get_vault_or_hsm')
+        g.custom_command('delete', 'delete_vault_or_hsm', supports_no_wait=True)
+        g.custom_command('purge', 'purge_vault_or_hsm', supports_no_wait=True)
         g.custom_command('set-policy', 'set_policy', supports_no_wait=True)
         g.custom_command('delete-policy', 'delete_policy', supports_no_wait=True)
-        g.custom_command('list-deleted', 'list_deleted_vault_or_hsm',
-                         doc_string_source=mgmt_vaults_entity.operations_docs_tmpl.format('list_deleted'))
+        g.custom_command('list-deleted', 'list_deleted_vault_or_hsm')
         g.custom_command('show-deleted', 'get_deleted_vault_or_hsm')
         g.generic_update_command(
             'update', setter_name='update_vault_setter', setter_type=kv_vaults_custom,
             custom_func_name='update_vault',
-            doc_string_source=mgmt_vaults_entity.models_docs_tmpl.format('VaultProperties'),
             supports_no_wait=True)
         g.wait_command('wait')
 
@@ -104,12 +98,9 @@ def load_command_table(self, _):
                                 client_factory=mgmt_hsms_entity.client_factory) as g:
             g.generic_update_command(
                 'update-hsm', setter_name='update_hsm_setter', setter_type=kv_hsms_custom,
-                custom_func_name='update_hsm', supports_no_wait=True,
-                doc_string_source=mgmt_hsms_entity.models_docs_tmpl.format('ManagedHsmProperties'))
+                custom_func_name='update_hsm', supports_no_wait=True)
             g.custom_wait_command('wait-hsm', 'wait_hsm')
-            g.custom_command('check-name', 'check_name_availability',
-                             doc_string_source=mgmt_hsms_entity.operations_docs_tmpl.
-                             format('check_mhsm_name_availability'))
+            g.custom_command('check-name', 'check_name_availability')
 
     with self.command_group('keyvault network-rule',
                             mgmt_vaults_entity.command_type,
@@ -146,58 +137,48 @@ def load_command_table(self, _):
     # Data Plane Commands
     if not is_azure_stack_profile(self):
         with self.command_group('keyvault backup', data_backup_entity.command_type) as g:
-            g.keyvault_custom('start', 'full_backup',
-                              doc_string_source=data_backup_entity.operations_docs_tmpl.format('begin_backup'))
+            g.keyvault_custom('start', 'full_backup')
 
         with self.command_group('keyvault restore', data_backup_entity.command_type) as g:
-            g.keyvault_custom('start', 'full_restore',
-                              doc_string_source=data_backup_entity.operations_docs_tmpl.format('begin_restore'))
+            g.keyvault_custom('start', 'full_restore')
 
-        with self.command_group('keyvault security-domain', private_data_entity.command_type) as g:
+        with self.command_group('keyvault security-domain', data_security_domain_entity.command_type) as g:
             g.keyvault_custom('init-recovery', 'security_domain_init_recovery')
             g.keyvault_custom('restore-blob', 'security_domain_restore_blob')
-            g.keyvault_custom('upload', 'security_domain_upload', supports_no_wait=True)
-            g.keyvault_custom('download', 'security_domain_download', supports_no_wait=True)
-            g.keyvault_custom('wait', '_wait_security_domain_operation')
-
-    with self.command_group('keyvault key', data_entity.command_type) as g:
-        g.keyvault_command('list', 'get_keys',
-                           transform=multi_transformers(
-                               filter_out_managed_resources,
-                               keep_max_results,
-                               extract_subresource_name(id_parameter='kid')))
-        g.keyvault_command('list-versions', 'get_key_versions',
-                           transform=multi_transformers(
-                               keep_max_results,
-                               extract_subresource_name(id_parameter='kid')))
-        g.keyvault_command('list-deleted', 'get_deleted_keys',
-                           transform=multi_transformers(
-                               keep_max_results,
-                               extract_subresource_name(id_parameter='kid')))
-        g.keyvault_command('show-deleted', 'get_deleted_key')
-        g.keyvault_command('delete', 'delete_key')
-        g.keyvault_command('purge', 'purge_deleted_key')
-        g.keyvault_command('recover', 'recover_deleted_key')
-        g.keyvault_custom('backup', 'backup_key',
-                          doc_string_source=data_entity.operations_docs_tmpl.format('backup_key'))
-        g.keyvault_custom('restore', 'restore_key', supports_no_wait=True,
-                          doc_string_source=data_entity.operations_docs_tmpl.format('restore_key'))
-        g.keyvault_custom('download', 'download_key')
+            g.keyvault_custom('upload', 'security_domain_upload', supports_no_wait=True,
+                              transform=transform_security_domain_output)
+            g.keyvault_custom('download', 'security_domain_download', supports_no_wait=True,
+                              transform=transform_security_domain_output)
+            g.keyvault_custom('wait', '_wait_security_domain_operation', transform=transform_security_domain_output)
 
     with self.command_group('keyvault key', data_key_entity.command_type) as g:
-        g.keyvault_custom('create', 'create_key', transform=transform_key_output,
-                          doc_string_source=data_entity.operations_docs_tmpl.format('create_key'))
+        g.keyvault_custom('create', 'create_key', transform=transform_key_output, validator=validate_key_create)
         g.keyvault_command('set-attributes', 'update_key_properties', transform=transform_key_output)
         g.keyvault_command('show', 'get_key', transform=transform_key_output)
         g.keyvault_custom('import', 'import_key', transform=transform_key_output)
         g.keyvault_custom('get-policy-template', 'get_policy_template', is_preview=True)
         g.keyvault_custom('encrypt', 'encrypt_key', is_preview=True, transform=transform_key_encryption_output)
         g.keyvault_custom('decrypt', 'decrypt_key', is_preview=True, transform=transform_key_decryption_output)
+        g.keyvault_custom('list', 'list_keys',
+                          transform=multi_transformers(keep_max_results, transform_key_list_output))
+        g.keyvault_command('list-versions', 'list_properties_of_key_versions',
+                           transform=multi_transformers(keep_max_results, transform_key_list_output))
+        g.keyvault_command('list-deleted', 'list_deleted_keys',
+                           transform=multi_transformers(keep_max_results, transform_key_list_output))
+        g.keyvault_command('show-deleted', 'get_deleted_key', transform=transform_key_output)
+        g.keyvault_custom('delete', 'delete_key', transform=transform_key_output)
+        g.keyvault_custom('recover', 'recover_key', transform=transform_key_output)
+        g.keyvault_command('purge', 'purge_deleted_key')
+        g.keyvault_custom('download', 'download_key')
+        g.keyvault_custom('backup', 'backup_key')
+        g.keyvault_custom('restore', 'restore_key', supports_no_wait=True, transform=transform_key_output)
 
     if not is_azure_stack_profile(self):
         with self.command_group('keyvault key', data_key_entity.command_type) as g:
             g.keyvault_command('random', 'get_random_bytes', transform=transform_key_random_output)
             g.keyvault_command('rotate', 'rotate_key', transform=transform_key_output)
+            g.keyvault_custom('sign', 'sign_key')
+            g.keyvault_custom('verify', 'verify_key')
 
         with self.command_group('keyvault key rotation-policy', data_key_entity.command_type) as g:
             g.keyvault_command('show', 'get_key_rotation_policy', )
@@ -271,7 +252,7 @@ def load_command_table(self, _):
         g.keyvault_custom('download', 'download_certificate')
         g.keyvault_custom('get-default-policy', 'get_default_policy')
 
-    data_api_version = str(get_api_version(self.cli_ctx, ResourceType.DATA_KEYVAULT)). \
+    data_api_version = str(get_api_version(self.cli_ctx, ResourceType.DATA_KEYVAULT_CERTIFICATES)). \
         replace('.', '_').replace('-', '_')
 
     if data_api_version != '2016_10_01':
@@ -329,39 +310,6 @@ def load_command_table(self, _):
             g.keyvault_command('show', 'get_setting')
             g.keyvault_custom('update', 'update_hsm_setting')
 
-    data_api_version = str(get_api_version(self.cli_ctx, ResourceType.DATA_KEYVAULT)).\
-        replace('.', '_').replace('-', '_')
-
-    if data_api_version != '2016_10_01':
-        with self.command_group('keyvault storage', data_entity.command_type) as g:
-            g.keyvault_command('add', 'set_storage_account')
-            g.keyvault_command('list', 'get_storage_accounts', transform=keep_max_results)
-            g.keyvault_command('show', 'get_storage_account')
-            g.keyvault_command('update', 'update_storage_account')
-            g.keyvault_command('remove', 'delete_storage_account')
-            g.keyvault_command('regenerate-key', 'regenerate_storage_account_key')
-            g.keyvault_command('list-deleted', 'get_deleted_storage_accounts', transform=keep_max_results)
-            g.keyvault_command('show-deleted', 'get_deleted_storage_account')
-            g.keyvault_command('purge', 'purge_deleted_storage_account')
-            g.keyvault_command('recover', 'recover_deleted_storage_account')
-            g.keyvault_custom('backup', 'backup_storage_account',
-                              doc_string_source=data_entity.operations_docs_tmpl.format('backup_storage_account'))
-            g.keyvault_custom('restore', 'restore_storage_account',
-                              doc_string_source=data_entity.operations_docs_tmpl.format('restore_storage_account'))
-
-    if data_api_version != '2016_10_01':
-        with self.command_group('keyvault storage sas-definition', data_entity.command_type) as g:
-            g.keyvault_command('create', 'set_sas_definition',
-                               doc_string_source=data_entity.operations_docs_tmpl.format('set_sas_definition'))
-            g.keyvault_command('list', 'get_sas_definitions', transform=keep_max_results)
-            g.keyvault_command('show', 'get_sas_definition')
-            g.keyvault_command('update', 'update_sas_definition',
-                               doc_string_source=data_entity.operations_docs_tmpl.format('update_sas_definition'))
-            g.keyvault_command('delete', 'delete_sas_definition')
-            g.keyvault_command('list-deleted', 'get_deleted_sas_definitions', transform=keep_max_results)
-            g.keyvault_command('show-deleted', 'get_deleted_sas_definition')
-            g.keyvault_command('recover', 'recover_deleted_sas_definition')
-
     if not is_azure_stack_profile(self):
         with self.command_group('keyvault region', mgmt_hsms_regions_entity.command_type,
                                 client_factory=mgmt_hsms_regions_entity.client_factory, min_api='2023-02-01') as g:
