@@ -4,6 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 import os
+import sys
 
 from knack.log import get_logger
 from knack.prompting import prompt_pass, NoTTYException
@@ -30,6 +31,22 @@ _CLOUD_CONSOLE_LOGIN_WARNING = ("Cloud Shell is automatically authenticated unde
                                 " Run 'az login' only if you need to use a different account")
 
 
+LOGIN_ANNOUNCEMENT = (
+    "[Announcements]\n"
+    "With the new Azure CLI login experience, you can select the subscription you want to use more easily. "
+    "Learn more about it and its configuration at https://go.microsoft.com/fwlink/?linkid=2271236\n\n"
+    "If you encounter any problem, please open an issue at https://aka.ms/azclibug\n")
+
+LOGIN_OUTPUT_WARNING = (
+    "[Warning] The login output has been updated. Please be aware that it no longer displays the full list of "
+    "available subscriptions by default.\n")
+
+USERNAME_PASSWORD_DEPRECATION_WARNING = (
+    "Authentication with username and password in the command line is strongly discouraged. "
+    "Use one of the recommended authentication methods based on your requirements. "
+    "For more details, see https://go.microsoft.com/fwlink/?linkid=2276314")
+
+
 def list_subscriptions(cmd, all=False, refresh=False):  # pylint: disable=redefined-builtin
     """List the imported subscriptions."""
     from azure.cli.core.api import load_subscriptions
@@ -69,7 +86,7 @@ def get_access_token(cmd, subscription=None, resource=None, scopes=None, resourc
     result = {
         'tokenType': creds[0],
         'accessToken': creds[1],
-        # 'expires_on': creds[2].get('expires_on', None),
+        'expires_on': creds[2]['expires_on'],
         'expiresOn': creds[2]['expiresOn'],
         'tenant': tenant
     }
@@ -98,8 +115,13 @@ def account_clear(cmd):
 
 
 # pylint: disable=inconsistent-return-statements, too-many-branches
-def login(cmd, username=None, password=None, service_principal=None, tenant=None, allow_no_subscriptions=False,
-          identity=False, use_device_code=False, use_cert_sn_issuer=None, scopes=None, client_assertion=None):
+def login(cmd, username=None, password=None, tenant=None, scopes=None, allow_no_subscriptions=False,
+          # Device code flow
+          use_device_code=False,
+          # Service principal
+          service_principal=None, certificate=None, use_cert_sn_issuer=None, client_assertion=None,
+          # Managed identity
+          identity=False):
     """Log in to access Azure subscriptions"""
 
     # quick argument usage check
@@ -111,6 +133,8 @@ def login(cmd, username=None, password=None, service_principal=None, tenant=None
         raise CLIError("usage error: '--use-sn-issuer' is only applicable with a service principal")
     if service_principal and not username:
         raise CLIError('usage error: --service-principal --username NAME --password SECRET --tenant TENANT')
+    if username and not service_principal and not identity:
+        logger.warning(USERNAME_PASSWORD_DEPRECATION_WARNING)
 
     interactive = False
 
@@ -124,7 +148,7 @@ def login(cmd, username=None, password=None, service_principal=None, tenant=None
         logger.warning(_CLOUD_CONSOLE_LOGIN_WARNING)
 
     if username:
-        if not (password or client_assertion):
+        if not (password or client_assertion or certificate):
             try:
                 password = prompt_pass('Password: ')
             except NoTTYException:
@@ -134,7 +158,17 @@ def login(cmd, username=None, password=None, service_principal=None, tenant=None
 
     if service_principal:
         from azure.cli.core.auth.identity import ServicePrincipalAuth
-        password = ServicePrincipalAuth.build_credential(password, client_assertion, use_cert_sn_issuer)
+        password = ServicePrincipalAuth.build_credential(
+            client_secret=password,
+            certificate=certificate, use_cert_sn_issuer=use_cert_sn_issuer,
+            client_assertion=client_assertion)
+
+    login_experience_v2 = cmd.cli_ctx.config.getboolean('core', 'login_experience_v2', fallback=True)
+    # Send login_experience_v2 config to telemetry
+    from azure.cli.core.telemetry import set_login_experience_v2
+    set_login_experience_v2(login_experience_v2)
+
+    select_subscription = interactive and sys.stdin.isatty() and sys.stdout.isatty() and login_experience_v2
 
     subscriptions = profile.login(
         interactive,
@@ -145,7 +179,21 @@ def login(cmd, username=None, password=None, service_principal=None, tenant=None
         scopes=scopes,
         use_device_code=use_device_code,
         allow_no_subscriptions=allow_no_subscriptions,
-        use_cert_sn_issuer=use_cert_sn_issuer)
+        use_cert_sn_issuer=use_cert_sn_issuer,
+        show_progress=select_subscription)
+
+    # Launch interactive account selection. No JSON output.
+    if select_subscription:
+        from ._subscription_selector import SubscriptionSelector
+        from azure.cli.core._profile import _SUBSCRIPTION_ID
+
+        selected = SubscriptionSelector(subscriptions)()
+        profile.set_active_subscription(selected[_SUBSCRIPTION_ID])
+
+        print(LOGIN_ANNOUNCEMENT)
+        logger.warning(LOGIN_OUTPUT_WARNING)
+        return
+
     all_subscriptions = list(subscriptions)
     for sub in all_subscriptions:
         sub['cloudName'] = sub.pop('environmentName', None)
@@ -165,11 +213,6 @@ def logout(cmd, username=None):
     profile.logout(username)
 
 
-def list_locations(cmd):
-    from azure.cli.core.commands.parameters import get_subscription_locations
-    return get_subscription_locations(cmd.cli_ctx)
-
-
 def check_cli(cmd):
     from azure.cli.core.file_util import (
         create_invoker_and_load_cmds_and_args, get_all_help)
