@@ -34,9 +34,17 @@ examples:
     text: >
         az postgres flexible-server create --location northeurope --resource-group testGroup \\
           --name testserver --admin-user username --admin-password password \\
-          --sku-name Standard_B1ms --tier Burstable --public-access 153.24.26.117 --storage-size 128 \\
-          --tags "key=value" --version 13 --high-availability Enabled --zone 1 \\
+          --sku-name Standard_D2s_v3 --tier GeneralPurpose --public-access 153.24.26.117 --storage-size 128 \\
+          --tags "key=value" --version 17 --high-availability ZoneRedundant --zone 1 \\
           --standby-zone 3
+  - name: >
+      Create a PostgreSQL flexible server using Premium SSD v2 Disks.
+    text: >
+      # set storage type to "PremiumV2_LRS" and provide values for Storage size (in GiB), IOPS (operations/sec), and Throughput (MB/sec).
+
+      az postgres flexible-server create --location northeurope --resource-group testGroup \\
+          --name testserver --admin-user username --admin-password password \\
+          --sku-name Standard_B1ms --tier Burstable --storage-type PremiumV2_LRS --storage-size 128 --iops 3000 --throughput 125
   - name: >
       Create a PostgreSQL flexible server with default parameters and public access enabled by default. \
       Resource group, server name, username, password, and default database will be created by CLI
@@ -199,6 +207,18 @@ examples:
 
       az postgres flexible-server create -g testGroup -n testServer --location testLocation --geo-redundant-backup Enabled \\
         --key $keyIdentifier --identity testIdentity --backup-key $geoKeyIdentifier --backup-identity geoIdentity
+
+  - name: >
+      Create flexible server with custom storage performance tier. Accepted values "P4", "P6", "P10", "P15", "P20", "P30", \\
+      "P40", "P50", "P60", "P70", "P80". Actual allowed values depend on the --storage-size selection for flexible server creation. \\
+      Default value for storage performance tier depends on the --storage-size selected for flexible server creation.
+    text: >
+      az postgres flexible-server create -g testGroup -n testServer --location testLocation --performance-tier P15
+
+  - name: >
+      create flexible server with storage auto-grow as Enabled. Accepted values Enabled / Disabled. Default value for storage auto-grow is "Disabled".
+    text: >
+      az postgres flexible-server create -g testGroup -n testServer --location testLocation --storage-auto-grow Enabled
 """
 
 helps['postgres flexible-server show'] = """
@@ -249,6 +269,14 @@ examples:
     text: az postgres flexible-server update --resource-group testGroup --name testserver --private-dns-zone testDNS2.postgres.database.azure.com
   - name: Update a flexible server to update private DNS zone for a VNET enabled server, using private DNS zone in the different resource group and subscription. Private DNS zone will be linked to the VNET if not already linked.
     text: az postgres flexible-server update --resource-group testGroup --name testserver --private-dns-zone /subscriptions/{SubId2}/resourceGroups/{testGroup2}/providers/Microsoft.Network/privateDnsZones/testDNS.postgres.database.azure.com
+  - name: Update a flexible server's storage to enable / disable storage auto-grow.
+    text: az postgres flexible-server update --resource-group testGroup --name testserver --storage-auto-grow Enabled
+  - name: Update a flexible server's storage to set custom storage performance tier.
+    text: az postgres flexible-server update --resource-group testGroup --name testserver --performance-tier P15
+  - name: Update a flexible server's storage to set IOPS (operations/sec). Server must be using Premium SSD v2 Disks.
+    text: az postgres flexible-server update --resource-group testGroup --name testserver --iops 3000
+  - name: Update a flexible server's storage to set Throughput (MB/sec). Server must be using Premium SSD v2 Disks.
+    text: az postgres flexible-server update --resource-group testGroup --name testserver --throughput 125
 """
 
 helps['postgres flexible-server restore'] = """
@@ -259,6 +287,21 @@ examples:
     text: az postgres flexible-server restore --resource-group testGroup --name testserverNew --source-server testserver --restore-time "2017-06-15T13:10:00Z"
   - name: Restore 'testserver' to current point-in-time as a new server 'testserverNew'.
     text: az postgres flexible-server restore --resource-group testGroup --name testserverNew --source-server testserver
+  - name: >
+      Restore 'testserver' to current point-in-time as a new server 'testserverNew' in a different resource group. \\
+      Here --resource-group is for the target server's resource group, and --source-server must be passed as resource ID.
+    text: >
+      az postgres flexible-server restore --resource-group testGroup --name testserverNew \\
+        --source-server /subscriptions/{testSubscription}/resourceGroups/{sourceResourceGroup}/providers/Microsoft.DBforPostgreSQL/flexibleServers/{sourceServerName}
+  - name: >
+      Restore 'testserver' to current point-in-time as a new server 'testserverNew' in a different subscription. \\
+      Here --resource-group is for the target server's resource group, and --source-server must be passed as resource ID. \\
+      This resource ID can be in a subscription different than the subscription used for az account set.
+    text: >
+      az postgres flexible-server restore --resource-group testGroup --name testserverNew \\
+        --source-server /subscriptions/{sourceSubscriptionId}/resourceGroups/{sourceResourceGroup}/providers/Microsoft.DBforPostgreSQL/flexibleServers/{sourceServerName}
+  - name: Restore 'testserver' to current point-in-time as a new server 'testserverNew' using Premium SSD v2 Disks by setting storage type to "PremiumV2_LRS"
+    text: az postgres flexible-server restore --resource-group testGroup --name testserverNew --source-server testserver --storage-type PremiumV2_LRS
 """
 
 helps['postgres flexible-server restart'] = """
@@ -408,6 +451,53 @@ examples:
     text: az postgres flexible-server firewall-rule delete --rule-name testRule --resource-group testGroup --name testserver
 """
 
+helps['postgres flexible-server virtual-endpoint'] = """
+type: group
+short-summary: Manage virtual endpoints for a PostgreSQL flexible server.
+"""
+
+helps['postgres flexible-server virtual-endpoint create'] = """
+type: command
+short-summary: Create a new virtual endpoint for a flexible server.
+examples:
+  - name: >
+      Create a virtual endpoint with writer endpoint.
+    text: >
+      az postgres flexible-server virtual-endpoint create --resource-group testGroup --server-name testserver --name test-virtual-endpoint --endpoint-type ReadWrite --members testReplica1
+"""
+
+helps['postgres flexible-server virtual-endpoint list'] = """
+type: command
+short-summary: List all virtual endpoints for a flexible server.
+example:
+  - name: List all virtual endpoints for a flexible server.
+    text: az postgres flexible-server virtual-endpoint list --resource-group testGroup --server-name testserver
+"""
+
+helps['postgres flexible-server virtual-endpoint show'] = """
+type: command
+short-summary: Get the details of a virtual endpoint.
+examples:
+  - name: Get the details of a virtual endpoint.
+    text: az postgres flexible-server virtual-endpoint show --resource-group testGroup --server-name testserver --name test-virtual-endpoint
+"""
+
+helps['postgres flexible-server virtual-endpoint update'] = """
+type: command
+short-summary: Update a virtual endpoint.
+examples:
+  - name: Update a virtual endpoint.
+    text: az postgres flexible-server virtual-endpoint update --resource-group testGroup --server-name testserver --name test-virtual-endpoint --endpoint-type ReadWrite --members testReplica1
+"""
+
+helps['postgres flexible-server virtual-endpoint delete'] = """
+type: command
+short-summary: Delete a virtual endpoint.
+examples:
+  - name: Delete a virtual endpoint.
+    text: az postgres flexible-server virtual-endpoint delete --resource-group testGroup --server-name testserver --name test-virtual-endpoint
+"""
+
 helps['postgres flexible-server migration'] = """
 type: group
 short-summary: Manage migration workflows for PostgreSQL Flexible Servers.
@@ -417,10 +507,104 @@ helps['postgres flexible-server migration create'] = """
 type: command
 short-summary: Create a new migration workflow for a flexible server.
 examples:
-  - name: Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the migrationConfig.json file. Use --migration-mode online for Online(with CDC) migration
-    text: az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver --migration-name testmigration --properties "migrationConfig.json" --migration-mode online
-  - name: Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the migrationConfig.json file. Use --migration-mode offline or no --migration-mode flag for Offline Migration.
-    text: az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver --migration-name testmigration --properties "migrationConfig.json"
+  - name: >
+      Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the properties file. The different properties are defined as: \n
+      sourceDbServerResourceId: Source server details. \n
+      adminCredentials: This parameter lists passwords for admin users for both the source server and the target PostgreSQL flexible server. \n
+      targetServerUserName: The default value is the admin user created during the creation of the PostgreSQL target flexible server, and the password provided is used for authentication against this user. \n
+      dbsToMigrate: Specify the list of databases that you want to migrate to Flexible Server. \n
+      overwriteDBsInTarget: When set to true (default), if the target server happens to have an existing database with the same name as the one you're trying to migrate, the migration service automatically overwrites the database. \n
+      Sample migrationConfig.json for PostgreSQLSingleServer shown below. \n
+      {
+        "properties": {
+          "sourceDBServerResourceId": "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/test-single-rg/providers/Microsoft.DBforPostgreSQL/servers/pg-single-1",
+          "secretParameters": {
+            "adminCredentials": {
+              "sourceServerPassword": "password",
+              "targetServerPassword": "password"
+            },
+            "sourceServerUserName": "testuser@pg-single-1",
+            "targetServerUserName": "fspguser"
+          },
+          "dBsToMigrate": [
+            "postgres"
+          ],
+          "overwriteDbsInTarget": "true"
+        }
+      }
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver \
+      --migration-name testmigration --properties "migrationConfig.json"
+  - name: >
+      Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the migrationConfig.json file. \
+      Use --migration-mode offline for Offline migration.
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver \
+      --migration-name testmigration --properties "migrationConfig.json" --migration-mode offline
+  - name: >
+      Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the migrationConfig.json file. \
+      Use --migration-mode online for Online(with CDC) migration. Use migration-option Validate for validate only request.
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver \
+      --migration-name testmigration --properties "migrationConfig.json" --migration-mode online --migration-option Validate
+  - name: >
+      Start a migration workflow on the target server identified by the parameters. The configurations of the migration should be specified in the migrationConfig.json file. \
+      Use --migration-option Migrate for Migrate Only request.
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver \
+      --migration-name testmigration --properties "migrationConfig.json" --migration-option Migrate
+  - name: >
+      To start a migration for other than PostgreSQLSingleServer, soureType and sslMode must be specified in properties file. These properties are defined as: \n
+      sourceType: Values can be - OnPremises, AWS_AURORA, AWS_RDS, AzureVM, PostgreSQLSingleServer \n
+      sslMode:  SSL modes for migration. SSL mode for PostgreSQLSingleServer is VerifyFull and Prefer/Require for other source types. \n
+      Sample migrationConfig.json shown below. \n
+      {
+        "properties": {
+          "sourceDBServerResourceId": "<<hostname or IP address>>:<<port>>@<<username>>",
+          "secretParameters": {
+            "adminCredentials": {
+              "sourceServerPassword": "password",
+              "targetServerPassword": "password"
+            },
+            "sourceServerUserName": "postgres",
+            "targetServerUserName": "fspguser"
+          },
+          "dBsToMigrate": [
+            "ticketdb","timedb","inventorydb"
+          ],
+          "overwriteDbsInTarget": "true",
+          "sourceType": "OnPremises",
+          "sslMode": "Prefer"
+        }
+      }
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver \
+        --migration-name testmigration --properties "migrationConfig.json"
+  - name: >
+      Start a private endpoint enabled migration workflow on the target server by specifying migrationRuntimeResourceId in properties file. This property is defined as: \n
+      migrationRuntimeResourceId: The resource ID of the migration runtime server that is responsible for migrating data between source and target server. \n
+      Sample migrationConfig.json shown below. \n
+      {
+        "properties": {
+          "sourceDBServerResourceId": "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/test-single-rg/providers/Microsoft.DBforPostgreSQL/servers/pg-single-1",
+          "migrationRuntimeResourceId": "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/testGroup/providers/Microsoft.DBforPostgreSQL/flexibleServers/testsourcemigration",
+          "secretParameters": {
+            "adminCredentials": {
+              "sourceServerPassword": "password",
+              "targetServerPassword": "password"
+            },
+            "sourceServerUserName": "testuser@pg-single-1",
+            "targetServerUserName": "fspguser"
+          },
+          "dBsToMigrate": [
+            "postgres"
+          ],
+          "overwriteDbsInTarget": "true"
+        }
+      }
+    text: >
+      az postgres flexible-server migration create --subscription xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --resource-group testGroup --name testserver --migration-name testmigration
+      --properties "migrationConfig.json"
 """
 
 helps['postgres flexible-server migration list'] = """
@@ -540,6 +724,16 @@ type: group
 short-summary: Manage flexible server backups.
 """
 
+helps['postgres flexible-server backup create'] = """
+type: command
+short-summary: Create a new backup for a flexible server.
+examples:
+  - name: >
+      Create a backup.
+    text: >
+      az postgres flexible-server backup create -g testgroup -n testsvr --backup-name testbackup
+"""
+
 helps['postgres flexible-server backup list'] = """
 type: command
 short-summary: List all the backups for a given server.
@@ -556,6 +750,51 @@ examples:
     text: az postgres flexible-server backup show -g testgroup -n testsvr --backup-name testbackup
 """
 
+helps['postgres flexible-server backup delete'] = """
+type: command
+short-summary: Delete a specific backup.
+examples:
+  - name: Delete a backup.
+    text: az postgres flexible-server backup delete -g testgroup -n testsvr --backup-name testbackup
+"""
+
+helps['postgres flexible-server long-term-retention'] = """
+type: group
+short-summary: Manage flexible server long-term-retention backups.
+"""
+
+helps['postgres flexible-server long-term-retention pre-check'] = """
+type: command
+short-summary: Performs all the checks that are needed for the subsequent long-term-retention backup operation to succeed.
+examples:
+  - name: Precheck if we can perform long-term-retention command on server 'server-name' on resource group 'resource-group-name' with backup name 'backup-name'.
+    text: az postgres flexible-server long-term-retention pre-check -g resource-group-name -b backup-name -n server-name
+"""
+
+helps['postgres flexible-server long-term-retention start'] = """
+type: command
+short-summary: Start long-term-retention backup for a flexible server. SAS URL parameter refers to the container SAS URL, inside the storage account, where the backups will be uploaded.
+examples:
+  - name: Create a backup with name 'backup-name' of server 'server-name' in resource group 'resource-group-name', using container with SAS URL '<sas-url>'.
+    text: az postgres flexible-server long-term-retention start -g resource-group-name -b backup-name -n server-name -u <sas-url>
+"""
+
+helps['postgres flexible-server long-term-retention show'] = """
+type: command
+short-summary: Show the details of a specific long-term-retention backup for a given server.
+examples:
+  - name: Show the details of long-term-retention backup 'testbackup' for 'testsvr'.
+    text: az postgres flexible-server long-term-retention show -g resource-group-name -n server-name -b backup-name
+"""
+
+helps['postgres flexible-server long-term-retention list'] = """
+type: command
+short-summary: List all the long-term-retention backups for a given server.
+examples:
+  - name: List all long-term-retention backups for 'testsvr'.
+    text: az postgres flexible-server long-term-retention list -g resource-group-name -n server-name
+"""
+
 helps['postgres flexible-server replica'] = """
 type: group
 short-summary: Manage read replicas.
@@ -565,20 +804,29 @@ helps['postgres flexible-server replica create'] = """
 type: command
 short-summary: Create a read replica for a server.
 examples:
-  - name: Create a read replica 'testReplicaServer' for 'testserver' with public or private access in the specified zone and location if available.
-    text: az postgres flexible-server replica create --replica-name testReplicaServer -g testGroup --source-server testserver --zone 3 --location testLocation
-  - name: Create a read replica 'testReplicaServer' with new subnet for 'testserver' with private access.
+  - name: Create a read replica 'testreplicaserver' for 'testserver' with public or private access in the specified zone and location if available.
+    text: az postgres flexible-server replica create --replica-name testreplicaserver -g testGroup --source-server testserver --zone 3 --location testLocation
+  - name: Create a read replica 'testreplicaserver' with new subnet for 'testserver' with private access.
     text: >
-      az postgres flexible-server replica create --replica-name testReplicaServer -g testGroup \\
+      az postgres flexible-server replica create --replica-name testreplicaserver -g testGroup \\
         --source-server testserver --zone 3 --location testLocation \\
         --vnet newVnet --subnet newSubnet \\
         --address-prefixes 172.0.0.0/16 --subnet-prefixes 172.0.0.0/24 \\
-        --private-dns-zone testDNS.postgres.database.azure.com
-  - name: Create a read replica 'testReplicaServer' for 'testserver' with public or private access \\
-        in the specified location if available. Since zone is not passed, it will automatically pick up zone in the \\
-        replica location which is different from source server, if available, else will pick up zone same as source server \\
-        in the replica location if available, else will set the zone as None, i.e. No preference
-    text: az postgres flexible-server replica create --replica-name testReplicaServer -g testGroup --source-server testserver --location testLocation
+        --private-dns-zone testDNS.postgres.database.azure.com \\
+        --tags "key=value"
+  - name: >
+      Create a read replica 'testreplicaserver' for 'testserver' with public or private access \
+      in the specified location if available. Since zone is not passed, it will automatically pick up zone in the \
+      replica location which is different from source server, if available, else will pick up zone same as source server \
+      in the replica location if available, else will set the zone as None, i.e. No preference
+    text: az postgres flexible-server replica create --replica-name testreplicaserver -g testGroup --source-server testserver --location testLocation
+  - name: Create a read replica 'testreplicaserver' for 'testserver' with custom --storage-size and --sku.
+    text: az postgres flexible-server replica create --replica-name testreplicaserver -g testGroup --source-server testserver --sku-name Standard_D4ds_v5 --storage-size 256
+  - name: Create a read replica 'testreplicaserver' for 'testserver', where 'testreplicaserver' is in a different resource group 'newTestGroup'. \
+      Here --resource-group is for the read replica's resource group, and --source-server must be passed as resource ID.
+    text: >
+      az postgres flexible-server replica create --replica-name testreplicaserver -g newTestGroup \
+        --source-server /subscriptions/{sourceSubscriptionId}/resourceGroups/{sourceResourceGroup}/providers/Microsoft.DBforPostgreSQL/flexibleServers/{sourceServerName} --location testLocation
 """
 
 helps['postgres flexible-server replica list'] = """
@@ -593,8 +841,22 @@ helps['postgres flexible-server replica stop-replication'] = """
 type: command
 short-summary: Stop replication to a read replica and make it a read/write server.
 examples:
-  - name: Stop replication to 'testReplicaServer' and make it a read/write server.
-    text: az postgres flexible-server replica stop-replication -g testGroup -n testReplicaServer
+  - name: Stop replication to 'testreplicaserver' and make it a read/write server.
+    text: az postgres flexible-server replica stop-replication -g testGroup -n testreplicaserver
+"""
+
+helps['postgres flexible-server replica promote'] = """
+type: command
+short-summary: Stop replication of a read replica and promote it to an independent server or as a primary server.
+examples:
+  - name: Stop replication to 'testreplicaserver' and promote it a standalone read/write server.
+    text: az postgres flexible-server replica promote -g testGroup -n testreplicaserver
+  - name: Stop replication to 'testreplicaserver' and promote it a standalone read/write server with forced data sync.
+    text: az postgres flexible-server replica promote -g testGroup -n testreplicaserver --promote-mode standalone --promote-option forced
+  - name: >
+      Stop replication to 'testreplicaserver' and promote it to primary server with planned data sync. \
+      The replica you are promoting must have the reader virtual endpoint assigned, or you will receive an error on promotion.
+    text: az postgres flexible-server replica promote -g testGroup -n testreplicaserver --promote-mode switchover --promote-option planned
 """
 
 helps['postgres flexible-server geo-restore'] = """
@@ -612,6 +874,13 @@ examples:
         --source-server testserver --vnet newVnet --subnet newSubnet \\
         --address-prefixes 172.0.0.0/16 --subnet-prefixes 172.0.0.0/24 \\
         --private-dns-zone testDNS.postgres.database.azure.com --location newLocation
+  - name: >
+      Geo-restore 'testserver' to current point-in-time as a new server 'testserverNew' in a different subscription / resource group. \\
+      Here --resource-group is for the target server's resource group, and --source-server must be passed as resource ID. \\
+      This resource ID can be in a subscription different than the subscription used for az account set.
+    text: >
+      az postgres flexible-server geo-restore --resource-group testGroup --name testserverNew --location newLocation \\
+        --source-server /subscriptions/{sourceSubscriptionId}/resourceGroups/{sourceResourceGroup}/providers/Microsoft.DBforPostgreSQL/flexibleServers/{sourceServerName}
 """
 
 helps['postgres flexible-server revive-dropped'] = """
@@ -632,8 +901,8 @@ helps['postgres flexible-server upgrade'] = """
 type: command
 short-summary: Upgrade the major version of a flexible server.
 examples:
-  - name: Upgrade server 'testsvr' to PostgreSQL major version 14.
-    text: az postgres flexible-server upgrade -g testgroup -n testsvr -v 14
+  - name: Upgrade server 'testsvr' to PostgreSQL major version 16.
+    text: az postgres flexible-server upgrade -g testgroup -n testsvr -v 16
 """
 
 helps['postgres flexible-server identity'] = """
@@ -719,3 +988,141 @@ examples:
   - name: Wait for an Active Directory administrator to be deleted.
     text: az postgres flexible-server ad-admin wait -g testgroup -s testsvr -i 00000000-0000-0000-0000-000000000000 --deleted
 """
+
+helps['postgres flexible-server advanced-threat-protection-setting'] = """
+type: group
+short-summary: Manage advanced threat protection setting for a PostgreSQL flexible server.
+"""
+
+helps['postgres flexible-server advanced-threat-protection-setting update'] = """
+type: command
+short-summary: Updates advanced threat protection setting state for a flexible server.
+examples:
+  - name: >
+      Enable advanced threat protection setting for a PostgreSQL flexible server.
+    text: >
+      az postgres flexible-server advanced-threat-protection-setting update --resource-group testGroup --server-name testserver --state Enabled
+  - name: >
+      Disable advanced threat protection setting for a PostgreSQL flexible server.
+    text: >
+      az postgres flexible-server advanced-threat-protection-setting update --resource-group testGroup --server-name testserver --state Disabled
+"""
+
+helps['postgres flexible-server advanced-threat-protection-setting show'] = """
+type: command
+short-summary: Get advanced threat protection settings for a PostgreSL flexible server.
+examples:
+  - name: Get the details of advanced threat protection setting for a flexible server.
+    text: az postgres flexible-server advanced-threat-protection-setting show --resource-group testGroup --server-name testserver
+  - name: Get the details of advanced threat protection setting for a flexible server in a different subscription.
+    text: az postgres flexible-server advanced-threat-protection-setting show --subscription testSubscription --resource-group testGroup --server-name testserver
+  - name: Get the details of advanced threat protection setting for a flexible server using --ids parameter.
+    text: az postgres flexible-server advanced-threat-protection-setting show --ids /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/testGroup/providers/Microsoft.DBforPostgreSQL/flexibleServers/testServer
+"""
+
+helps['postgres flexible-server server-logs'] = """
+type: group
+short-summary: Manage server logs (log files) for a PostgreSQL flexible server.
+"""
+
+helps['postgres flexible-server server-logs download'] = """
+type: command
+short-summary: Download log files for a PostgreSQL flexible server.
+examples:
+  - name: >
+      Downloads log files f1 and f2 to the current directory from the server 'testsvr'. Please note that f1 and f2 should match the log file name including the foldername, for instance serverlogs/f1.log
+    text: >
+      az postgres flexible-server server-logs download -g testgroup -s testsvr -n serverlogs/f1.log serverlogs/f2.log
+"""
+
+helps['postgres flexible-server server-logs list'] = """
+type: command
+short-summary: List log files for a PostgreSQL flexible server.
+examples:
+  - name: List log files for 'testsvr' modified in the last 72 hours (default value).
+    text: az postgres flexible-server server-logs list -g testgroup -s testsvr
+  - name: List log files for 'testsvr' modified in the last 10 hours.
+    text: az postgres flexible-server server-logs list -g testgroup -s testsvr --file-last-written 10
+  - name: List log files for 'testsvr' less than 30Kb in size.
+    text: az postgres flexible-server server-logs list -g testgroup -s testsvr --max-file-size 30
+  - name: List log files for 'testsvr' containing name 'serverlogs'.
+    text: az postgres flexible-server server-logs list -g testgroup -s testsvr --subscription testSubscription --filename-contains serverlogs
+"""
+
+helps['postgres flexible-server private-endpoint-connection'] = """
+type: group
+short-summary: Manage PostgreSQL flexible server private endpoint connections.
+"""
+
+helps['postgres flexible-server private-endpoint-connection list'] = """
+type: command
+short-summary: List all private endpoint connections associated with a PostgreSQL flexible server.
+examples:
+  - name: List all private endpoint connections associated with a PostgreSQL flexible server.
+    text: az postgres flexible-server private-endpoint-connection list -g testgroup -s testsvr
+"""
+
+helps['postgres flexible-server private-endpoint-connection show'] = """
+type: command
+short-summary: Show details of a private endpoint connection associated with a PostgreSQL flexible server.
+examples:
+  - name: Show details of a private endpoint connection associated with a PostgreSQL flexible server.
+    text: az postgres flexible-server private-endpoint-connection show -g testgroup -s testsvr -n pec-connection.40e3d3a8-7d8f-41eb-8462-1cd05bc3e33b
+"""
+
+helps['postgres flexible-server private-endpoint-connection approve'] = """
+type: command
+short-summary: Approve the specified private endpoint connection associated with a PostgreSQL flexible server.
+examples:
+  - name: Approve a private endpoint connection associated with a PostgreSQL flexible server.
+    text: >
+      az postgres flexible-server private-endpoint-connection approve -g testgroup -s testsvr \
+        -n pec-connection.40e3d3a8-7d8f-41eb-8462-1cd05bc3e33b \
+        --description "Approve connection"
+"""
+
+helps['postgres flexible-server private-endpoint-connection reject'] = """
+type: command
+short-summary: Reject the specified private endpoint connection associated with a PostgreSQL flexible server.
+examples:
+  - name: Reject a private endpoint connection associated with a PostgreSQL flexible server.
+    text: >
+      az postgres flexible-server private-endpoint-connection reject -g testgroup -s testsvr \
+        -n pec-connection.40e3d3a8-7d8f-41eb-8462-1cd05bc3e33b \
+        --description "Reject connection"
+"""
+
+helps['postgres flexible-server private-endpoint-connection delete'] = """
+type: command
+short-summary: Delete the specified private endpoint connection associated with a PostgreSQL flexible server.
+examples:
+  - name: Delete a private endpoint connection associated with a PostgreSQL flexible server.
+    text: >
+      az postgres flexible-server private-endpoint-connection delete -g testgroup -s testsvr \
+        --id /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testgroup/providers/Microsoft.DBforPostgreSQL/flexibleServers/testsvr/privateEndpointConnections/pec-connection.40e3d3a8-7d8f-41eb-8462-1cd05bc3e33b
+"""
+
+helps['postgres flexible-server private-link-resource'] = """
+type: group
+short-summary: Get Private link resource for a PostgreSQL flexible server.
+"""
+
+helps['postgres flexible-server private-link-resource list'] = """
+type: command
+short-summary: List private link resources associated with a PostgreSQL flexible server.
+examples:
+  - name: List private link resources associated with a PostgreSQL flexible server.
+    text: az postgres flexible-server private-link-resource list -g testgroup -s testsvr
+"""
+
+helps['postgres flexible-server private-link-resource show'] = """
+type: command
+short-summary: Get private link  resource for a PostgreSQL flexible server.
+examples:
+  - name: Get the private link  resource for a flexible server.
+    text: az postgres flexible-server private-link-resource show --resource-group testGroup --server-name testserver
+  - name: Get the private link  resource for a flexible server in a different subscription.
+    text: az postgres flexible-server private-link-resource show --subscription testSubscription --resource-group testGroup --server-name testserver
+  - name: Get the private link resource for a flexible server using --ids parameter.
+    text: az postgres flexible-server private-link-resource show --ids /subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/testGroup/providers/Microsoft.DBforPostgreSQL/flexibleServers/testServer
+"""
