@@ -16,7 +16,8 @@ from azure.cli.core.commands.parameters import (
     get_three_state_flag)
 from azure.cli.command_modules.rdbms.validators import configuration_value_validator, validate_subnet, \
     tls_validator, public_access_validator, maintenance_window_validator, ip_address_validator, \
-    retention_validator, firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities
+    retention_validator, firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities, \
+    virtual_endpoint_name_validator
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 
 from .randomname.generate import generate_username
@@ -59,7 +60,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('administrator_login_password', options_list=['--admin-password', '-p'], help='The password of the administrator. Minimum 8 characters and maximum 128 characters. Password must contain characters from three of the following categories: English uppercase letters, English lowercase letters, numbers, and non-alphanumeric characters.')
             c.argument('ssl_enforcement', arg_type=get_enum_type(['Enabled', 'Disabled']), options_list=['--ssl-enforcement'], help='Enable or disable ssl enforcement for connections to server. Default is Enabled.')
             c.argument('minimal_tls_version', arg_type=get_enum_type(['TLS1_0', 'TLS1_1', 'TLS1_2', 'TLSEnforcementDisabled']), options_list=['--minimal-tls-version'], help='Set the minimal TLS version for connections to server when SSL is enabled. Default is TLSEnforcementDisabled.', validator=tls_validator)
-            c.argument('public_network_access', options_list=['--public-network-access', '--public'], help='Enable or disable public network access to server. When disabled, only connections made through Private Links can reach this server. Allowed values are : Enabled, Disabled, all, 0.0.0.0, <SingleIP>, <StartIP-DestinationIP>. Default is Enabled.')
+            c.argument('public_network_access', options_list=['--public-network-access', '--public'], help='Enable or disable public network access to server. When disabled, only connections made through Private Links can reach this server. Allowed values are : `Enabled`, `Disabled`, `all`, `0.0.0.0`, `<SingleIP>`, `<StartIP-DestinationIP>`. Default is `Enabled`.')
             c.argument('tier', arg_type=get_enum_type(['Basic', 'GeneralPurpose', 'MemoryOptimized']), options_list=['--performance-tier'], help='The performance tier of the server.')
             c.argument('capacity', options_list=['--vcore'], type=int, help='Number of vcore.')
             c.argument('family', options_list=['--family'], arg_type=get_enum_type(['Gen4', 'Gen5']), help='Hardware generation.')
@@ -221,7 +222,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     _complex_params('postgres')
 
     # Flexible-server
-    # pylint: disable=too-many-statements, too-many-locals, too-many-branches
+    # pylint: disable=too-many-locals, too-many-branches
     def _flexible_server_params(command_group):
 
         server_name_arg_type = CLIArgumentType(
@@ -311,18 +312,56 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                  'To learn more about IOPS based on compute and storage, refer to IOPS in Azure Database for MySQL Flexible Server'
         )
 
+        iops_v2_arg_type = CLIArgumentType(
+            type=int,
+            options_list=['--iops'],
+            help='Value of IOPS in (operations/sec) to be allocated for this server. '
+                 'This value can only be updated if flexible server is using Premium SSD v2 Disks.'
+        )
+
+        throughput_arg_type = CLIArgumentType(
+            type=int,
+            options_list=['--throughput'],
+            help='Storage throughput in (MB/sec) for the server. '
+                 'This value can only be updated if flexible server is using Premium SSD v2 Disks.'
+        )
+
+        create_default_db_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['Enabled', 'Disabled']),
+            options_list=['--create-default-database', '-c'],
+            help='Enable or disable the creation of default database flexibleserverdb. Default value is Enabled.'
+        )
+
         auto_grow_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['Enabled', 'Disabled']),
             options_list=['--storage-auto-grow'],
             help='Enable or disable autogrow of the storage. Default value is Enabled.'
         )
 
+        storage_type_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['PremiumV2_LRS', 'Premium_LRS']),
+            options_list=['--storage-type'],
+            help='Storage type for the server. Allowed values are Premium_LRS and PremiumV2_LRS. Default value is Premium_LRS.'
+                 'Must set iops and throughput if using PremiumV2_LRS.'
+        )
+
+        storage_type_restore_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['PremiumV2_LRS']),
+            options_list=['--storage-type'],
+            help='Storage type for the new server. Allowed value is PremiumV2_LRS. Default value is none.'
+        )
+
         auto_scale_iops_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['Enabled', 'Disabled']),
             options_list=['--auto-scale-iops'],
             help='Enable or disable the auto scale iops. Default value is Disabled.'
         )
 
+        performance_tier_arg_type = CLIArgumentType(
+            options_list=['--performance-tier'],
+            help='Performance tier of the server.'
+        )
+
         yes_arg_type = CLIArgumentType(
             options_list=['--yes', '-y'],
             action='store_true',
@@ -395,7 +434,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         )
 
         pg_version_upgrade_arg_type = CLIArgumentType(
-            arg_type=get_enum_type(['12', '13', '14']),
+            arg_type=get_enum_type(['12', '13', '14', '15', '16']),
             options_list=['--version', '-v'],
             help='Server major version.'
         )
@@ -486,6 +525,37 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             help='Show connection strings for PgBouncer.'
         )
 
+        promote_mode_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['standalone', 'switchover']),
+            help='Whether to promote read replica to an independent server or promote it as a primary server.'
+        )
+
+        promote_option_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['planned', 'forced']),
+            help='Whether to sync data before promoting read replica or promote as soon as possible.'
+        )
+
+        virtual_endpoint_arg_type = CLIArgumentType(
+            metavar='NAME',
+            options_list=['--name', '-n'],
+            id_part='name',
+            help="Name of the virtual endpoint. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.",
+            local_context_attribute=LocalContextAttribute(
+                name='virtual_endpoint_name',
+                actions=[LocalContextAction.SET, LocalContextAction.GET],
+                scopes=['{} flexible-server'.format(command_group)]))
+
+        endpoint_type_arg_type = CLIArgumentType(
+            options_list=['--endpoint-type', '-t'],
+            arg_type=get_enum_type(['ReadWrite']),
+            help='Type of connection point for virtual endpoint.'
+        )
+
+        members_type = CLIArgumentType(
+            options_list=['--members', '-m'],
+            help='The read replicas the virtual endpoints point to.'
+        )
+
         with self.argument_context('{} flexible-server'.format(command_group)) as c:
             c.argument('resource_group_name', arg_type=resource_group_name_type)
             c.argument('server_name', arg_type=server_name_arg_type)
@@ -496,10 +566,16 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('tier', default='GeneralPurpose', arg_type=tier_arg_type)
                 c.argument('sku_name', default='Standard_D2s_v3', arg_type=sku_name_arg_type)
                 c.argument('storage_gb', default='128', arg_type=storage_gb_arg_type)
-                c.argument('version', default='13', arg_type=version_arg_type)
+                c.argument('version', default='16', arg_type=version_arg_type)
                 c.argument('backup_retention', default=7, arg_type=pg_backup_retention_arg_type)
                 c.argument('active_directory_auth', default='Disabled', arg_type=active_directory_auth_arg_type)
                 c.argument('password_auth', default='Enabled', arg_type=password_auth_arg_type)
+                c.argument('auto_grow', default='Disabled', arg_type=auto_grow_arg_type)
+                c.argument('storage_type', default=None, arg_type=storage_type_arg_type)
+                c.argument('iops', default=None, arg_type=iops_v2_arg_type)
+                c.argument('throughput', default=None, arg_type=throughput_arg_type)
+                c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
+                c.argument('create_default_db', default='Enabled', arg_type=create_default_db_arg_type)
             elif command_group == 'mysql':
                 c.argument('tier', default='Burstable', arg_type=tier_arg_type)
                 c.argument('sku_name', default='Standard_B1ms', arg_type=sku_name_arg_type)
@@ -558,6 +634,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('geo_redundant_backup', default='Disabled', arg_type=geo_redundant_backup_arg_type)
                 c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
                 c.argument('backup_byok_key', arg_type=backup_key_arg_type)
+                c.argument('storage_type', default=None, arg_type=storage_type_restore_arg_type)
 
         with self.argument_context('{} flexible-server geo-restore'. format(command_group)) as c:
             c.argument('location', arg_type=get_location_type(self.cli_ctx), required=True)
@@ -617,6 +694,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('byok_identity', arg_type=identity_arg_type)
             c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
             c.argument('backup_byok_key', arg_type=backup_key_arg_type)
+            c.argument('public_access', arg_type=public_access_update_arg_type)
             if command_group == 'mysql':
                 c.argument('auto_grow', arg_type=auto_grow_arg_type)
                 c.argument('auto_scale_iops', arg_type=auto_scale_iops_arg_type)
@@ -626,8 +704,11 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
                 c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
                 c.argument('disable_data_encryption', arg_type=disable_data_encryption_arg_type)
-                c.argument('public_access', arg_type=public_access_update_arg_type)
             elif command_group == 'postgres':
+                c.argument('auto_grow', arg_type=auto_grow_arg_type)
+                c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
+                c.argument('iops', default=None, arg_type=iops_v2_arg_type)
+                c.argument('throughput', default=None, arg_type=throughput_arg_type)
                 c.argument('backup_retention', arg_type=pg_backup_retention_arg_type)
                 c.argument('active_directory_auth', arg_type=active_directory_auth_arg_type)
                 c.argument('password_auth', arg_type=password_auth_arg_type)
@@ -717,6 +798,41 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('database_name', arg_type=database_name_arg_type)
             c.argument('show_pg_bouncer', arg_type=pg_bouncer_arg_type)
 
+        # virtual-endpoint
+        for scope in ['create', 'delete', 'list', 'show', 'update']:
+            argument_context_string = '{} flexible-server virtual-endpoint {}'.format(command_group, scope)
+            with self.argument_context(argument_context_string) as c:
+                c.argument('resource_group_name', arg_type=resource_group_name_type)
+                c.argument('server_name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+                c.argument('virtual_endpoint_name', options_list=['--name', '-n'], arg_type=virtual_endpoint_arg_type, validator=virtual_endpoint_name_validator)
+
+        with self.argument_context('{} flexible-server long-term-retention list'.format(command_group)) as c:
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server long-term-retention show'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='Backup name.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server long-term-retention start'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new long-term-retention backup.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+            c.argument('sas_url', options_list=['--sas-url', '-u'], help='Container SAS URL.')
+
+        with self.argument_context('{} flexible-server long-term-retention pre-check'.format(command_group)) as c:
+            c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new long-term-retention backup.')
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        for scope in ['create', 'update']:
+            argument_context_string = '{} flexible-server virtual-endpoint {}'.format(command_group, scope)
+            with self.argument_context(argument_context_string) as c:
+                c.argument('endpoint_type', options_list=['--endpoint-type', '-t'], arg_type=endpoint_type_arg_type,
+                           help='Virtual Endpoints offer two distinct types of connection points. Writer endpoint (Read/Write), this endpoint always points to the current primary server. Read-only endpoint, This endpoint can point to either a read replica or primary server. ')
+                c.argument('members', options_list=['--members', '-m'], arg_type=members_type,
+                           help='The read replicas the virtual endpoints point to. ')
+
+        with self.argument_context('{} flexible-server virtual-endpoint delete'.format(command_group)) as c:
+            c.argument('yes', arg_type=yes_arg_type)
+
         with self.argument_context('{} flexible-server replica list'.format(command_group)) as c:
             c.argument('server_name', id_part=None, options_list=['--name', '-n'], help='Name of the source server.')
 
@@ -734,13 +850,21 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
                 c.argument('byok_key', arg_type=key_arg_type)
                 c.argument('byok_identity', arg_type=identity_arg_type)
+                c.argument('tier', arg_type=tier_arg_type)
+                c.argument('sku_name', arg_type=sku_name_arg_type)
+                c.argument('storage_gb', arg_type=storage_gb_arg_type)
+                c.argument('performance_tier', default=None, arg_type=performance_tier_arg_type)
                 c.argument('yes', arg_type=yes_arg_type)
+                c.argument('tags', arg_type=tags_type)
             if command_group == 'mysql':
                 c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']),
                            help='Determines the public access. ')
 
-        with self.argument_context('{} flexible-server replica stop-replication'.format(command_group)) as c:
+        with self.argument_context('{} flexible-server replica promote'.format(command_group)) as c:
             c.argument('server_name', arg_type=server_name_arg_type)
+            c.argument('promote_mode', options_list=['--promote-mode'], required=False, arg_type=promote_mode_arg_type)
+            c.argument('promote_option', options_list=['--promote-option'], required=False, arg_type=promote_option_arg_type)
+            c.argument('yes', arg_type=yes_arg_type)
 
         with self.argument_context('{} flexible-server deploy setup'.format(command_group)) as c:
             c.argument('resource_group_name', arg_type=resource_group_name_type)
@@ -771,7 +895,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('max_file_size', type=int, help='The file size limitation to filter files.')
 
         # backups
-        if command_group == 'mysql':
+        if command_group != 'mariadb':
             with self.argument_context('{} flexible-server backup create'.format(command_group)) as c:
                 c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new backup.')
 
@@ -781,6 +905,11 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         with self.argument_context('{} flexible-server backup list'.format(command_group)) as c:
             c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
 
+        if command_group == 'postgres':
+            with self.argument_context('{} flexible-server backup delete'.format(command_group)) as c:
+                c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new backup.')
+                c.argument('yes', arg_type=yes_arg_type)
+
         # identity
         with self.argument_context('{} flexible-server identity'.format(command_group)) as c:
             c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
@@ -807,6 +936,57 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('principal_type', options_list=['--type', '-t'], default='User', arg_type=get_enum_type(['User', 'Group', 'ServicePrincipal', 'Unknown']), help='Type of the Azure AD administrator.')
             c.argument('identity', help='Name or ID of identity used for AAD Authentication.', validator=validate_identity)
 
+        # server advanced threat protection settings
+        for scope in ['update', 'show']:
+            argument_context_string = '{} flexible-server advanced-threat-protection-setting {}'.format(command_group, scope)
+            with self.argument_context(argument_context_string) as c:
+                c.argument('resource_group_name', arg_type=resource_group_name_type)
+                c.argument('server_name', id_part='name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server advanced-threat-protection-setting update'.format(command_group)) as c:
+            c.argument('state',
+                       options_list=['--state'],
+                       required=True,
+                       help='State of advanced threat protection setting.',
+                       arg_type=get_enum_type(['Enabled', 'Disabled']))
+
+        # server log files
+        for scope in ['download', 'list']:
+            argument_context_string = '{} flexible-server server-logs {}'.format(command_group, scope)
+            with self.argument_context(argument_context_string) as c:
+                c.argument('resource_group_name', arg_type=resource_group_name_type)
+                c.argument('server_name', id_part='name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+
+        with self.argument_context('{} flexible-server server-logs download'.format(command_group)) as c:
+            c.argument('file_name', options_list=['--name', '-n'], nargs='+', help='Space-separated list of log filenames on the server to download.')
+
+        with self.argument_context('{} flexible-server server-logs list'.format(command_group)) as c:
+            c.argument('filename_contains', help='The pattern that file name should match.')
+            c.argument('file_last_written', type=int, help='Integer in hours to indicate file last modify time.', default=72)
+            c.argument('max_file_size', type=int, help='The file size limitation to filter files.')
+
+        for scope in ['list', 'show', 'delete', 'approve', 'reject']:
+            with self.argument_context('{} flexible-server private-endpoint-connection {}'.format(command_group, scope)) as c:
+                c.argument('resource_group_name', arg_type=resource_group_name_type)
+                if scope == "list":
+                    c.argument('server_name', options_list=['--server-name', '-s'], id_part='name', arg_type=server_name_arg_type, required=False)
+                else:
+                    c.argument('server_name', options_list=['--server-name', '-s'], id_part='name', arg_type=server_name_arg_type, required=False,
+                               help='Name of the Server. Required if --id is not specified')
+                    c.argument('private_endpoint_connection_name', options_list=['--name', '-n'], required=False,
+                               help='The name of the private endpoint connection associated with the Server. '
+                               'Required if --id is not specified')
+                    c.extra('connection_id', options_list=['--id'], required=False,
+                            help='The ID of the private endpoint connection associated with the Server. '
+                            'If specified --server-name/-s and --name/-n, this should be omitted.')
+                if scope == "approve" or scope == "reject":
+                    c.argument('description', help='Comments for {} operation.'.format(scope), required=True)
+
+        for scope in ['list', 'show']:
+            with self.argument_context('{} flexible-server private-link-resource {}'.format(command_group, scope)) as c:
+                c.argument('resource_group_name', arg_type=resource_group_name_type)
+                c.argument('server_name', options_list=['--server-name', '-s'], id_part='name', arg_type=server_name_arg_type, required=False)
+
         # GTID
         if command_group == 'mysql':
             with self.argument_context('{} flexible-server gtid reset'.format(command_group)) as c:
@@ -832,6 +1012,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                                help='Name of the migration.')
                     c.argument('migration_mode', arg_type=migration_id_arg_type, options_list=['--migration-mode'], required=False,
                                help='Either offline or online(with CDC) migration', choices=['offline', 'online'], default='offline')
+                    c.argument('migration_option', arg_type=migration_id_arg_type, options_list=['--migration-option'], required=False,
+                               help='Supported Migration Option. Default is ValidateAndMigrate.', choices=['Validate', 'ValidateAndMigrate', 'Migrate'], default='ValidateAndMigrate')
                     c.argument('tags', tags_type)
                     c.argument('location', arg_type=get_location_type(self.cli_ctx))
                 elif scope == "show":
