@@ -3,6 +3,7 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
+from azure.cli.command_modules.rdbms.validators import validate_private_endpoint_connection_id
 from azure.cli.core.commands import CliCommandType
 
 from azure.cli.command_modules.rdbms._client_factory import (
@@ -12,9 +13,17 @@ from azure.cli.command_modules.rdbms._client_factory import (
     cf_postgres_flexible_db,
     cf_postgres_flexible_location_capabilities,
     cf_postgres_flexible_backups,
+    cf_postgres_flexible_ltr_backups,
+    cf_postgres_flexible_operations,
     cf_postgres_flexible_replica,
     cf_postgres_flexible_adadmin,
-    cf_postgres_flexible_migrations)
+    cf_postgres_flexible_migrations,
+    cf_postgres_flexible_private_endpoint_connection,
+    cf_postgres_flexible_private_endpoint_connections,
+    cf_postgres_flexible_private_link_resources,
+    cf_postgres_flexible_virtual_endpoints,
+    cf_postgres_flexible_server_threat_protection_settings,
+    cf_postgres_flexible_server_log_files)
 
 from ._transformers import (
     table_transform_output,
@@ -32,22 +41,22 @@ from ._transformers import (
 def load_flexibleserver_command_table(self, _):
     # Flexible server SDKs:
     postgres_flexible_servers_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#ServersOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#ServersOperations.{}',
         client_factory=cf_postgres_flexible_servers
     )
 
     postgres_flexible_firewall_rule_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#FirewallRulesOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#FirewallRulesOperations.{}',
         client_factory=cf_postgres_flexible_firewall_rules
     )
 
     postgres_flexible_config_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#ConfigurationsOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#ConfigurationsOperations.{}',
         client_factory=cf_postgres_flexible_config
     )
 
     postgres_flexible_db_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#DatabasesOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#DatabasesOperations.{}',
         client_factory=cf_postgres_flexible_db
     )
 
@@ -57,25 +66,65 @@ def load_flexibleserver_command_table(self, _):
     )
 
     postgres_flexible_backups_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#BackupsOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#BackupsOperations.{}',
         client_factory=cf_postgres_flexible_backups
     )
 
+    postgres_flexible_ltr_backup_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#LtrBackupOperationsOperations.{}',
+        client_factory=cf_postgres_flexible_ltr_backups
+    )
+
+    postgres_flexible_operations_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#FlexibleServerOperations.{}',
+        client_factory=cf_postgres_flexible_operations
+    )
+
     postgres_flexible_replica_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#ReplicasOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#ReplicasOperations.{}',
         client_factory=cf_postgres_flexible_replica
     )
 
     postgres_flexible_adadmin_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#AdministratorsOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#AdministratorsOperations.{}',
         client_factory=cf_postgres_flexible_adadmin
     )
 
     postgres_flexible_migrations_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.rdbms.postgresql_flexibleservers.operations#MigrationsOperations.{}',
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#MigrationsOperations.{}',
         client_factory=cf_postgres_flexible_migrations
     )
 
+    postgres_flexible_virtual_endpoints_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#VirtualEndpointsOperations.{}',
+        client_factory=cf_postgres_flexible_virtual_endpoints
+    )
+
+    postgres_flexible_server_threat_protection_settings_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#ServerThreatProtectionSettingsOperations.{}',
+        client_factory=cf_postgres_flexible_server_threat_protection_settings
+    )
+
+    postgres_flexible_server_log_files_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#LogFilesOperations.{}',
+        client_factory=cf_postgres_flexible_server_log_files
+    )
+
+    postgres_flexible_server_private_endpoint_connection_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#PrivateEndpointConnectionOperations.{}',
+        client_factory=cf_postgres_flexible_private_endpoint_connection
+    )
+
+    postgres_flexible_server_private_endpoint_connections_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#PrivateEndpointConnectionsOperations.{}',
+        client_factory=cf_postgres_flexible_private_endpoint_connections
+    )
+
+    postgres_flexible_server_private_link_resources_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.postgresqlflexibleservers.operations#PrivateLinkResourcesOperations.{}',
+        client_factory=cf_postgres_flexible_private_link_resources
+    )
+
     # MERU COMMANDS
     flexible_server_custom_common = CliCommandType(
         operations_tmpl='azure.cli.command_modules.rdbms.flexible_server_custom_common#{}')
@@ -127,6 +176,15 @@ def load_flexibleserver_command_table(self, _):
         g.custom_command('update', 'migration_update_func', custom_command_type=flexible_servers_custom_postgres)
         g.custom_command('check-name-availability', 'migration_check_name_availability', custom_command_type=flexible_servers_custom_postgres)
 
+    with self.command_group('postgres flexible-server virtual-endpoint', postgres_flexible_virtual_endpoints_sdk,
+                            custom_command_type=flexible_servers_custom_postgres,
+                            client_factory=cf_postgres_flexible_virtual_endpoints) as g:
+        g.custom_command('create', 'virtual_endpoint_create_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('delete', 'virtual_endpoint_delete_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_show_command('show', 'virtual_endpoint_show_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('list', 'virtual_endpoint_list_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('update', 'virtual_endpoint_update_func', custom_command_type=flexible_servers_custom_postgres)
+
     with self.command_group('postgres flexible-server parameter', postgres_flexible_config_sdk,
                             custom_command_type=flexible_servers_custom_postgres,
                             client_factory=cf_postgres_flexible_config, table_transformer=table_transform_output_parameters) as g:
@@ -158,6 +216,18 @@ def load_flexibleserver_command_table(self, _):
                             client_factory=cf_postgres_flexible_backups) as g:
         g.command('list', 'list_by_server', transform=transform_backups_list)
         g.show_command('show', 'get', transform=transform_backup)
+        g.custom_command('create', 'backup_create_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('delete', 'backup_delete_func', custom_command_type=flexible_servers_custom_postgres)
+
+    with self.command_group('postgres flexible-server long-term-retention', postgres_flexible_ltr_backup_sdk,
+                            client_factory=cf_postgres_flexible_ltr_backups) as g:
+        g.command('list', 'list_by_server', transform=transform_backups_list)
+        g.show_command('show', 'get', transform=transform_backup)
+
+    with self.command_group('postgres flexible-server long-term-retention', postgres_flexible_operations_sdk,
+                            client_factory=cf_postgres_flexible_operations) as g:
+        g.custom_command('pre-check', 'ltr_precheck_func', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('start', 'ltr_start_func', custom_command_type=flexible_servers_custom_postgres)
 
     with self.command_group('postgres flexible-server replica', postgres_flexible_replica_sdk) as g:
         g.command('list', 'list_by_server')
@@ -166,7 +236,8 @@ def load_flexibleserver_command_table(self, _):
                             custom_command_type=flexible_servers_custom_postgres,
                             client_factory=cf_postgres_flexible_servers) as g:
         g.custom_command('create', 'flexible_replica_create', supports_no_wait=True)
-        g.custom_command('stop-replication', 'flexible_replica_stop', confirmation=True)
+        g.custom_command('stop-replication', 'flexible_replica_stop', confirmation=True, deprecate_info=g.deprecate(redirect='postgres flexible-server replica promote', hide=True))
+        g.custom_command('promote', 'flexible_replica_promote', confirmation=True)
 
     with self.command_group('postgres flexible-server identity', postgres_flexible_servers_sdk,
                             custom_command_type=flexible_servers_custom_postgres,
@@ -184,3 +255,34 @@ def load_flexibleserver_command_table(self, _):
         g.custom_command('list', 'flexible_server_ad_admin_list')
         g.custom_show_command('show', 'flexible_server_ad_admin_show')
         g.custom_wait_command('wait', 'flexible_server_ad_admin_show')
+
+    with self.command_group('postgres flexible-server advanced-threat-protection-setting', postgres_flexible_server_threat_protection_settings_sdk,
+                            custom_command_type=flexible_servers_custom_postgres,
+                            client_factory=cf_postgres_flexible_server_threat_protection_settings) as g:
+        g.custom_show_command('show', 'flexible_server_threat_protection_get', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('update', 'flexible_server_threat_protection_update', custom_command_type=flexible_servers_custom_postgres)
+
+    with self.command_group('postgres flexible-server server-logs', postgres_flexible_server_log_files_sdk,
+                            custom_command_type=flexible_servers_custom_postgres,
+                            client_factory=cf_postgres_flexible_server_log_files) as g:
+        g.custom_command('list', 'flexible_server_list_log_files_with_filter', custom_command_type=flexible_servers_custom_postgres)
+        g.custom_command('download', 'flexible_server_download_log_files', custom_command_type=flexible_servers_custom_postgres)
+
+    with self.command_group('postgres flexible-server private-endpoint-connection', postgres_flexible_server_private_endpoint_connections_sdk) as g:
+        g.command('list', 'list_by_server')
+        g.show_command('show', 'get', validator=validate_private_endpoint_connection_id)
+
+    with self.command_group('postgres flexible-server private-endpoint-connection', postgres_flexible_server_private_endpoint_connection_sdk,
+                            custom_command_type=flexible_servers_custom_postgres,
+                            client_factory=cf_postgres_flexible_private_endpoint_connection) as g:
+        g.command('delete', 'begin_delete', validator=validate_private_endpoint_connection_id)
+        g.custom_command('approve', 'flexible_server_approve_private_endpoint_connection', custom_command_type=flexible_servers_custom_postgres,
+                         validator=validate_private_endpoint_connection_id)
+        g.custom_command('reject', 'flexible_server_reject_private_endpoint_connection', custom_command_type=flexible_servers_custom_postgres,
+                         validator=validate_private_endpoint_connection_id)
+
+    with self.command_group('postgres flexible-server private-link-resource', postgres_flexible_server_private_link_resources_sdk,
+                            custom_command_type=flexible_servers_custom_postgres,
+                            client_factory=cf_postgres_flexible_private_link_resources) as g:
+        g.command('list', 'list_by_server')
+        g.custom_show_command('show', 'flexible_server_private_link_resource_get', custom_command_type=flexible_servers_custom_postgres)
