@@ -7,7 +7,8 @@ import re
 from knack.prompting import prompt_pass, NoTTYException
 from knack.util import CLIError
 from knack.log import get_logger
-from msrestazure.tools import parse_resource_id, resource_id, is_valid_resource_id, is_valid_resource_name
+import math
+from azure.mgmt.core.tools import parse_resource_id, resource_id, is_valid_resource_id, is_valid_resource_name
 from azure.cli.core.azclierror import ValidationError, ArgumentUsageError
 from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_subscription_id
 from azure.cli.core.commands.validators import (
@@ -23,7 +24,9 @@ from ._flexible_server_util import (get_mysql_versions, get_mysql_skus, get_mysq
                                     get_postgres_skus, get_postgres_storage_sizes, get_postgres_tiers,
                                     _is_resource_name)
 from ._flexible_server_location_capabilities_util import (get_postgres_location_capability_info,
-                                                          get_postgres_server_capability_info)
+                                                          get_postgres_server_capability_info,
+                                                          get_performance_tiers,
+                                                          get_performance_tiers_for_storage)
 
 logger = get_logger(__name__)
 
@@ -296,9 +299,12 @@ def _mysql_iops_validator(iops, auto_io_scaling, instance):
 def pg_arguments_validator(db_context, location, tier, sku_name, storage_gb, server_name=None, zone=None,
                            standby_availability_zone=None, high_availability=None, subnet=None, public_access=None,
                            version=None, instance=None, geo_redundant_backup=None,
-                           byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None):
+                           byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None,
+                           auto_grow=None, performance_tier=None,
+                           storage_type=None, iops=None, throughput=None):
     validate_server_name(db_context, server_name, 'Microsoft.DBforPostgreSQL/flexibleServers')
-    if not instance:
+    is_create = not instance
+    if is_create:
         list_location_capability_info = get_postgres_location_capability_info(
             db_context.cmd,
             location)
@@ -308,40 +314,100 @@ def pg_arguments_validator(db_context, location, tier, sku_name, storage_gb, ser
             resource_group=parse_resource_id(instance.id)["resource_group"],
             server_name=instance.name)
     sku_info = list_location_capability_info['sku_info']
+    sku_info = {k.lower(): v for k, v in sku_info.items()}
     single_az = list_location_capability_info['single_az']
     geo_backup_supported = list_location_capability_info['geo_backup_supported']
     _network_arg_validator(subnet, public_access)
     _pg_tier_validator(tier, sku_info)  # need to be validated first
     if tier is None and instance is not None:
-        tier = instance.sku.tier
+        tier = instance.sku.tier.lower()
+    if "supported_storageV2_size" in sku_info[tier.lower()]:
+        supported_storageV2_size = sku_info[tier.lower()]["supported_storageV2_size"]
+    else:
+        supported_storageV2_size = None
+    _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_redundant_backup, performance_tier,
+                               supported_storageV2_size, iops, throughput, instance)
+    _pg_storage_performance_tier_validator(performance_tier,
+                                           sku_info,
+                                           tier,
+                                           instance.storage.storage_size_gb if storage_gb is None else storage_gb)
     if geo_redundant_backup is None and instance is not None:
         geo_redundant_backup = instance.backup.geo_redundant_backup
     _pg_georedundant_backup_validator(geo_redundant_backup, geo_backup_supported)
-    _pg_storage_validator(storage_gb, sku_info, tier, instance)
+    _pg_storage_validator(storage_gb, sku_info, tier, storage_type, iops, throughput, instance)
     _pg_sku_name_validator(sku_name, sku_info, tier, instance)
     _pg_high_availability_validator(high_availability, standby_availability_zone, zone, tier, single_az, instance)
-    _pg_version_validator(version, list_location_capability_info['server_versions'])
+    _pg_version_validator(version, list_location_capability_info['server_versions'], is_create)
     pg_byok_validator(byok_identity, byok_key, backup_byok_identity, backup_byok_key, geo_redundant_backup, instance)
 
 
-def _pg_storage_validator(storage_gb, sku_info, tier, instance):
+def _pg_storage_validator(storage_gb, sku_info, tier, storage_type, iops, throughput, instance):
+    is_ssdv2 = storage_type == "PremiumV2_LRS" or instance is not None and instance.storage.type == "PremiumV2_LRS"
+    # storage_gb range validation
     if storage_gb is not None:
         if instance is not None:
             original_size = instance.storage.storage_size_gb
             if original_size > storage_gb:
-                raise CLIError('Updating storage cannot be smaller than '
-                               'the original storage size {} GiB.'.format(original_size))
-        storage_sizes = get_postgres_storage_sizes(sku_info, tier)
-        if storage_gb not in storage_sizes:
-            storage_sizes = sorted([int(size) for size in storage_sizes])
-            raise CLIError('Incorrect value for --storage-size : Allowed values(in GiB) : {}'
-                           .format(storage_sizes))
+                raise CLIError('Updating storage cannot be smaller than the original storage size {} GiB.'
+                               .format(original_size))
+        if not is_ssdv2:
+            storage_sizes = get_postgres_storage_sizes(sku_info, tier)
+            if storage_gb not in storage_sizes:
+                storage_sizes = sorted([int(size) for size in storage_sizes])
+                raise CLIError('Incorrect value for --storage-size : Allowed values(in GiB) : {}'
+                               .format(storage_sizes))
+
+    # ssdv2 range validation
+    if is_ssdv2 and (storage_gb is not None or throughput is not None or iops is not None):
+        _valid_ssdv2_range(storage_gb, sku_info, tier, iops, throughput, instance)
+
+
+def _valid_ssdv2_range(storage_gb, sku_info, tier, iops, throughput, instance):
+    storage_gib = storage_gb if storage_gb is not None else instance.storage.storage_size_gb
+    storage_iops = iops if iops is not None else instance.storage.iops
+    storage_throughput = throughput if throughput is not None else instance.storage.throughput
+
+    # find min and max values for storage
+    sku_tier = tier.lower()
+    supported_storageV2_size = sku_info[sku_tier]["supported_storageV2_size"]
+    min_storage = instance.storage.storage_size_gb if instance is not None else supported_storageV2_size
+    max_storage = sku_info[sku_tier]["supported_storageV2_size_max"]
+    if not (min_storage <= storage_gib <= max_storage):
+        raise CLIError('The requested value for storage size does not fall between {} and {} GiB.'
+                       .format(min_storage, max_storage))
+
+    storage = storage_gib * 1.07374182
+    # find min and max values for IOPS
+    min_iops = sku_info[sku_tier]["supported_storageV2_iops"]
+    if sku_info[sku_tier]["supported_storageV2_iops"] < math.floor(max(0, storage - 6) * 500 + min_iops):
+        max_iops = sku_info[sku_tier]["supported_storageV2_iops_max"]
+    else:
+        max_iops = math.floor(max(0, storage - 6) * 500 + min_iops)
+
+    if not (min_iops <= storage_iops <= max_iops):
+        raise CLIError('The requested value for IOPS does not fall between {} and {} operations/sec.'
+                       .format(min_iops, max_iops))
+
+    # find min and max values for throughout
+    min_throughout = sku_info[sku_tier]["supported_storageV2_throughput"]
+    if storage > 6:
+        max_storage_throughout = math.floor(max(0.25 * storage_iops, min_throughout))
+    else:
+        max_storage_throughout = min_throughout
+    if sku_info[sku_tier]["supported_storageV2_throughput_max"] < max_storage_throughout:
+        max_throughout = sku_info[sku_tier]["supported_storageV2_throughput_max"]
+    else:
+        max_throughout = max_storage_throughout
+
+    if not (min_throughout <= storage_throughput <= max_throughout):
+        raise CLIError('The requested value for throughput does not fall between {} and {} MB/sec.'
+                       .format(min_throughout, max_throughout))
 
 
 def _pg_tier_validator(tier, sku_info):
     if tier:
-        tiers = get_postgres_tiers(sku_info)
-        if tier not in tiers:
+        tiers = [item.lower() for item in get_postgres_tiers(sku_info)]
+        if tier.lower() not in tiers:
             raise CLIError('Incorrect value for --tier. Allowed values : {}'.format(tiers))
 
 
@@ -349,17 +415,44 @@ def _pg_sku_name_validator(sku_name, sku_info, tier, instance):
     if instance is not None:
         tier = instance.sku.tier if tier is None else tier
     if sku_name:
-        skus = get_postgres_skus(sku_info, tier)
-        if sku_name not in skus:
+        skus = [item.lower() for item in get_postgres_skus(sku_info, tier.lower())]
+        if sku_name.lower() not in skus:
             raise CLIError('Incorrect value for --sku-name. The SKU name does not match {} tier. '
                            'Specify --tier if you did not. Or CLI will set GeneralPurpose as the default tier. '
                            'Allowed values : {}'.format(tier, skus))
 
 
-def _pg_version_validator(version, versions):
+def _pg_storage_performance_tier_validator(performance_tier, sku_info, tier=None, storage_size=None):
+    if performance_tier:
+        tiers = get_postgres_tiers(sku_info)
+        if tier.lower() in [item.lower() for item in tiers]:
+            if storage_size is None:
+                performance_tiers = [item.lower() for item in
+                                     get_performance_tiers(sku_info[tier.lower()]["storage_edition"])]
+            else:
+                performance_tiers = [item.lower() for item in
+                                     get_performance_tiers_for_storage(sku_info[tier.lower()]["storage_edition"],
+                                     storage_size=storage_size)]
+
+            if performance_tier.lower() not in performance_tiers:
+                raise CLIError('Incorrect value for --performance-tier for storage-size: {}.'
+                               ' Allowed values : {}'.format(storage_size, performance_tiers))
+
+
+def _pg_version_validator(version, versions, is_create):
     if version:
         if version not in versions:
             raise CLIError('Incorrect value for --version. Allowed values : {}'.format(versions))
+        if version == '12':
+            logger.warning("Support for PostgreSQL 12 has officially ended. As a result, "
+                           "the option to select version 12 will be removed in the near future. "
+                           "We recommend selecting PostgreSQL 13 or a later version for "
+                           "all future operations.")
+
+    if is_create:
+        # Warning for upcoming breaking change to default value of pg version
+        logger.warning("The default value for the PostgreSQL server major version "
+                       "will be updating to 17 in the near future.")
 
 
 def _pg_high_availability_validator(high_availability, standby_availability_zone, zone, tier, single_az, instance):
@@ -422,13 +515,13 @@ def _network_arg_validator(subnet, public_access):
 
 
 def maintenance_window_validator(ns):
-    options = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Disabled", "disabled"]
+    options = ["sun", "mon", "tue", "wed", "thu", "fri", "sat", "disabled"]
     if ns.maintenance_window:
         parsed_input = ns.maintenance_window.split(':')
         if not parsed_input or len(parsed_input) > 3:
             raise CLIError('Incorrect value for --maintenance-window. '
                            'Enter <Day>:<Hour>:<Minute>. Example: "Mon:8:30" to schedule on Monday, 8:30 UTC')
-        if len(parsed_input) >= 1 and parsed_input[0] not in options:
+        if len(parsed_input) >= 1 and parsed_input[0].lower() not in options:
             raise CLIError('Incorrect value for --maintenance-window. '
                            'The first value means the scheduled day in a week or '
                            'can be "Disabled" to reset maintenance window. '
@@ -470,8 +563,8 @@ def public_access_validator(ns):
 
 
 def _validate_start_and_end_ip_address_order(start_ip, end_ip):
-    start_ip_elements = start_ip.split('.')
-    end_ip_elements = end_ip.split('.')
+    start_ip_elements = [int(octet) for octet in start_ip.split('.')]
+    end_ip_elements = [int(octet) for octet in end_ip.split('.')]
 
     for idx in range(4):
         if start_ip_elements[idx] < end_ip_elements[idx]:
@@ -498,19 +591,29 @@ def _validate_ip(ips):
 
 def _validate_ranges_in_ip(ip):
     parsed_ip = ip.split('.')
-    if len(parsed_ip) == 4 and _valid_range(int(parsed_ip[0])) and _valid_range(int(parsed_ip[1])) \
-       and _valid_range(int(parsed_ip[2])) and _valid_range(int(parsed_ip[3])):
+    if len(parsed_ip) == 4 and _valid_range(parsed_ip[0]) and _valid_range(parsed_ip[1]) \
+       and _valid_range(parsed_ip[2]) and _valid_range(parsed_ip[3]):
         return True
     return False
 
 
 def _valid_range(addr_range):
-    if 0 <= addr_range <= 255:
+    if addr_range.isdigit() and 0 <= int(addr_range) <= 255:
         return True
     return False
 
 
+def virtual_endpoint_name_validator(ns):
+    if not re.search(r'^(?=[a-z0-9].*)(?=.*[a-z-])(?!.*[^a-z0-9-])(?=.*[a-z0-9]$)', ns.virtual_endpoint_name):
+        raise ValidationError("The virtual endpoint name can only contain 0-9, a-z, and \'-\'. "
+                              "The virtual endpoint name must not start or end in a hyphen. "
+                              "Additionally, the name of the virtual endpoint must be at least 3 characters "
+                              "and no more than 63 characters in length. ")
+
+
 def firewall_rule_name_validator(ns):
+    if not ns.firewall_rule_name:
+        return
     if not re.search(r'^[a-zA-Z0-9][-_a-zA-Z0-9]{1,126}[_a-zA-Z0-9]$', ns.firewall_rule_name):
         raise ValidationError("The firewall rule name can only contain 0-9, a-z, A-Z, \'-\' and \'_\'. "
                               "Additionally, the name of the firewall rule must be at least 3 characters "
@@ -541,6 +644,19 @@ def validate_server_name(db_context, server_name, type_):
         raise ValidationError(result.message)
 
 
+def validate_migration_runtime_server(cmd, migrationInstanceResourceId, target_resource_group_name, target_server_name):
+    id_comps = parse_resource_id(migrationInstanceResourceId)
+    runtime_server_resource_resource_type = id_comps['resource_type'].lower()
+    if "flexibleservers" != runtime_server_resource_resource_type:
+        raise ValidationError("Migration Runtime Resource ID provided should be Flexible server.")
+
+    server_operations_client = cf_postgres_flexible_servers(cmd.cli_ctx, '_')
+    target_server = server_operations_client.get(target_resource_group_name, target_server_name)
+    if target_server.id.lower() == migrationInstanceResourceId.lower():
+        raise ValidationError("Migration Runtime server is same as Target Flexible server. "
+                              "Please change the values accordingly.")
+
+
 def validate_private_dns_zone(db_context, server_name, private_dns_zone, private_dns_zone_suffix):
     cmd = db_context.cmd
     if db_context.command_group == 'postgres':
@@ -575,7 +691,8 @@ def validate_mysql_replica(server):
                               "Scale up the source server to General Purpose or Memory Optimized. ")
 
 
-def validate_postgres_replica(cmd, tier, location, list_location_capability_info=None):
+def validate_postgres_replica(cmd, tier, location, instance, sku_name,
+                              storage_gb, performance_tier=None, list_location_capability_info=None):
     # Tier validation
     if tier == 'Burstable':
         raise ValidationError("Read replica is not supported for the Burstable pricing tier. "
@@ -584,6 +701,14 @@ def validate_postgres_replica(cmd, tier, location, list_location_capability_info
     if not list_location_capability_info:
         list_location_capability_info = get_postgres_location_capability_info(cmd, location)
 
+    sku_info = list_location_capability_info['sku_info']
+    _pg_tier_validator(tier, sku_info)  # need to be validated first
+    _pg_sku_name_validator(sku_name, sku_info, tier, instance)
+    _pg_storage_performance_tier_validator(performance_tier,
+                                           sku_info,
+                                           tier,
+                                           storage_gb)
+
 
 def validate_mysql_tier_update(instance, tier):
     if instance.sku.tier in ['GeneralPurpose', 'MemoryOptimized'] and tier == 'Burstable':
@@ -666,3 +791,53 @@ def validate_byok_identity(cmd, namespace):
 def validate_identities(cmd, namespace):
     if namespace.identities:
         namespace.identities = [_validate_identity(cmd, namespace, identity) for identity in namespace.identities]
+
+
+def _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_redundant_backup, performance_tier,
+                               supported_storageV2_size, iops, throughput, instance):
+    is_create_ssdv2 = storage_type == "PremiumV2_LRS"
+    is_update_ssdv2 = instance is not None and instance.storage.type == "PremiumV2_LRS"
+
+    if is_create_ssdv2:
+        if supported_storageV2_size is None:
+            raise CLIError('Storage type set to PremiumV2_LRS is not supported for this region.')
+        if iops is None or throughput is None:
+            raise CLIError('To set --storage-type, required to provide --iops and --throughput.')
+    elif instance is None and (throughput is not None or iops is not None):
+        raise CLIError('To provide values for both --iops and --throughput, '
+                       'please set "--storage-type" to "PremiumV2_LRS".')
+
+    if is_create_ssdv2 or is_update_ssdv2:
+        if auto_grow and auto_grow.lower() != 'disabled':
+            raise ValidationError("Storage Auto-grow is not supported for servers with Premium SSD V2.")
+        if high_availability and high_availability.lower() != 'disabled':
+            raise ValidationError("High availability is not supported for servers with Premium SSD V2.")
+        if geo_redundant_backup and geo_redundant_backup.lower() != 'disabled':
+            raise ValidationError("Geo-redundancy is not supported for servers with Premium SSD V2.")
+        if performance_tier:
+            raise ValidationError("Performance tier is not supported for servers with Premium SSD V2.")
+    else:
+        if throughput is not None:
+            raise CLIError('Updating throughput is only capable for server created with Premium SSD v2.')
+        if iops is not None:
+            raise CLIError('Updating storage iops is only capable for server created with Premium SSD v2.')
+
+
+def check_resource_group(resource_group_name):
+    # check if rg is already null originally
+    if (not resource_group_name):
+        return False
+
+    # replace single and double quotes with empty string
+    resource_group_name = resource_group_name.replace("'", '')
+    resource_group_name = resource_group_name.replace('"', '')
+
+    # check if rg is empty after removing quotes
+    if (not resource_group_name):
+        return False
+    return True
+
+
+def validate_resource_group(resource_group_name):
+    if (not check_resource_group(resource_group_name)):
+        raise CLIError('Resource group name cannot be empty.')
