@@ -198,7 +198,6 @@ class TestCustom(unittest.TestCase):
         parameters_path = os.path.join(curr_dir, 'param-validation-params.json').replace('\\', '\\\\')
 
         template = get_file_json(template_path, preserve_order=True)
-        template_param_defs = template.get('parameters', {})
 
         # test different ways of passing in parameters
         tests = [
@@ -238,7 +237,60 @@ class TestCustom(unittest.TestCase):
 
         for i, test in enumerate(tests):
             parameter_list = test['parameter_list']
-            result_parameters = _process_parameters(template_param_defs, parameter_list)
+            result_parameters = _process_parameters(template, parameter_list)
+            self.assertEqual(result_parameters, test['expected'], i)
+
+    def test_deployment_parameters_with_type_references(self):
+
+        curr_dir = os.path.dirname(os.path.realpath(__file__))
+        template_path = os.path.join(curr_dir, 'param-validation-template-$ref-indirection.json').replace('\\', '\\\\')
+        parameters_path = os.path.join(curr_dir, 'param-validation-params.json').replace('\\', '\\\\')
+
+        template = get_file_json(template_path, preserve_order=True)
+
+        # test different ways of passing in parameters
+        tests = [
+            {  # empty JSON works
+                "parameter_list": [["{}"]],
+                "expected": {},
+            },
+            {  # empty parameters works
+                "parameter_list": [],
+                "expected": {},
+            },
+            {  # loading from file
+                "parameter_list": [[parameters_path]],
+                "expected": {"stringParam": {"value": "foo"}, "intParam": {"value": 10}, "madeupParam": {"value": "bar"}},
+            },
+            {  # KEY=VALUE syntax with extra equal sign
+                "parameter_list": [['stringParam=foo=bar']],
+                "expected": {"stringParam": {"value": "foo=bar"}},
+            },
+            {  # raw JSON (same as @file)
+                "parameter_list": [['{\"stringParam\": {\"value\": \"foo\"}}']],
+                "expected": {"stringParam": {"value": "foo"}},
+            },
+            {  # multiple KEY=VALUE
+                "parameter_list": [['stringParam=foo', 'intParam=3']],
+                "expected": {"stringParam": {"value": "foo"}, "intParam": {"value": 3}},
+            },
+            {  # KEY=VALUE where last in wins
+                "parameter_list": [['stringParam=foo', 'stringParam=bar']],
+                "expected": {"stringParam": {"value": "bar"}},
+            },
+            {  # file loading overriden by KEY=VALUE
+                "parameter_list": [[parameters_path], ['stringParam=bar']],
+                "expected": {"stringParam": {"value": "bar"}, "intParam": {"value": 10}, "madeupParam": {"value": "bar"}},
+            },
+            {
+                "parameter_list": [['boolParam=true', 'tupleParam=[21]']],
+                "expected": {"boolParam": {"value": True}, "tupleParam": {"value": [21]}},
+            }
+        ]
+
+        for i, test in enumerate(tests):
+            parameter_list = test['parameter_list']
+            result_parameters = _process_parameters(template, parameter_list)
             self.assertEqual(result_parameters, test['expected'], i)
 
     def test_deployment_missing_values(self):
@@ -252,7 +304,7 @@ class TestCustom(unittest.TestCase):
         template_param_defs = template.get('parameters', {})
 
         parameter_list = [[parameters_path], [parameters_with_reference_path]]
-        result_parameters = _process_parameters(template_param_defs, parameter_list)
+        result_parameters = _process_parameters(template, parameter_list)
         missing_parameters = _find_missing_parameters(result_parameters, template)
 
         # ensure that parameters with default values are not considered missing
@@ -272,10 +324,9 @@ class TestCustom(unittest.TestCase):
         parameters_with_reference_path = os.path.join(curr_dir, 'param-validation-ref-params.json').replace('\\', '\\\\')
 
         template = get_file_json(template_path, preserve_order=True)
-        template_param_defs = template.get('parameters', {})
 
         parameter_list = [[parameters_path], [parameters_with_reference_path]]
-        result_parameters = _process_parameters(template_param_defs, parameter_list)
+        result_parameters = _process_parameters(template, parameter_list)
         missing_parameters = _find_missing_parameters(result_parameters, template)
 
         param_file_order = ["[u'secureParam', u'boolParam', u'enumParam', u'arrayParam', u'objectParam']",
@@ -291,10 +342,9 @@ class TestCustom(unittest.TestCase):
         parameters_with_reference_path = os.path.join(curr_dir, 'param-validation-ref-params.json').replace('\\', '\\\\')
 
         template = get_file_json(template_path, preserve_order=False)
-        template_param_defs = template.get('parameters', {})
 
         parameter_list = [[parameters_path], [parameters_with_reference_path]]
-        result_parameters = _process_parameters(template_param_defs, parameter_list)
+        result_parameters = _process_parameters(template, parameter_list)
         missing_parameters = _find_missing_parameters(result_parameters, template)
 
         param_alpha_order = ["[u'arrayParam', u'boolParam', u'enumParam', u'objectParam', u'secureParam']",
