@@ -23,7 +23,7 @@ import dateutil.parser
 from dateutil.relativedelta import relativedelta
 from knack.log import get_logger
 from knack.util import CLIError, todict
-from msrestazure.azure_exceptions import CloudError
+from azure.core.exceptions import HttpResponseError
 
 from azure.cli.core.profiles import ResourceType
 from azure.cli.core.util import get_file_json, shell_safe_json_parse, is_guid
@@ -50,9 +50,11 @@ CREDENTIAL_WARNING = (
     "The output includes credentials that you must protect. Be sure that you do not include these credentials in "
     "your code or check the credentials into your source control. For more information, see https://aka.ms/azadsp-cli")
 
-SCOPE_WARNING = (
-    "--scope argument will become required for creating a role assignment in the breaking change release of the fall "
-    "of 2023. Please explicitly specify --scope.")
+CLASSIC_ADMINISTRATOR_WARNING = (
+    "Azure classic subscription administrators will be retired on August 31, 2024. "
+    "After August 31, 2024, all classic administrators risk losing access to the subscription. "
+    "Delete classic administrators who no longer need access or assign an Azure RBAC role for fine-grained access "
+    "control. Learn more: https://go.microsoft.com/fwlink/?linkid=2238474")
 
 logger = get_logger(__name__)
 
@@ -100,7 +102,7 @@ def _create_update_role_definition(cmd, role_definition, for_update):
         scopes = (scopes_in_definition if scopes_in_definition else
                   ['/subscriptions/' + definitions_client._config.subscription_id])
         if role_resource_id:
-            from msrestazure.tools import parse_resource_id
+            from azure.mgmt.core.tools import parse_resource_id
             role_id = parse_resource_id(role_resource_id)['name']
             role_name = role_definition['roleName']
         else:
@@ -148,13 +150,11 @@ def _search_role_definitions(cli_ctx, definitions_client, name, scopes, custom_r
     return []
 
 
-def create_role_assignment(cmd, role, assignee=None, assignee_object_id=None, resource_group_name=None,
-                           scope=None, assignee_principal_type=None, description=None,
+def create_role_assignment(cmd, role, scope,
+                           assignee=None, assignee_object_id=None,
+                           assignee_principal_type=None, description=None,
                            condition=None, condition_version=None, assignment_name=None):
     """Check parameters are provided correctly, then call _create_role_assignment."""
-    if not scope:
-        logger.warning(SCOPE_WARNING)
-
     if bool(assignee) == bool(assignee_object_id):
         raise CLIError('usage error: --assignee STRING | --assignee-object-id GUID')
 
@@ -183,13 +183,13 @@ def create_role_assignment(cmd, role, assignee=None, assignee_object_id=None, re
             principal_type = _get_principal_type_from_object_id(cmd.cli_ctx, assignee_object_id)
 
     try:
-        return _create_role_assignment(cmd.cli_ctx, role, object_id, resource_group_name, scope, resolve_assignee=False,
+        return _create_role_assignment(cmd.cli_ctx, role, object_id, scope=scope, resolve_assignee=False,
                                        assignee_principal_type=principal_type, description=description,
                                        condition=condition, condition_version=condition_version,
                                        assignment_name=assignment_name)
     except Exception as ex:  # pylint: disable=broad-except
         if _error_caused_by_role_assignment_exists(ex):  # for idempotent
-            return list_role_assignments(cmd, assignee, role, resource_group_name, scope)[0]
+            return list_role_assignments(cmd, assignee=assignee, role=role, scope=scope)[0]
         raise
 
 
@@ -219,6 +219,9 @@ def list_role_assignments(cmd, assignee=None, role=None, resource_group_name=Non
     :param include_groups: include extra assignments to the groups of which the user is a
     member(transitively).
     '''
+    if include_classic_administrators:
+        logger.warning(CLASSIC_ADMINISTRATOR_WARNING)
+
     graph_client = _graph_client_factory(cmd.cli_ctx)
     authorization_client = _auth_client_factory(cmd.cli_ctx, scope)
     assignments_client = authorization_client.role_assignments
@@ -272,7 +275,7 @@ def list_role_assignments(cmd, assignee=None, role=None, resource_group_name=Non
                 if principal_dics.get(worker.get_role_property(i, 'principalId')):
                     worker.set_role_property(i, 'principalName',
                                              principal_dics[worker.get_role_property(i, 'principalId')])
-        except (CloudError, GraphError) as ex:
+        except (HttpResponseError, GraphError) as ex:
             # failure on resolving principal due to graph permission should not fail the whole thing
             logger.info("Failed to resolve graph object information per error '%s'", ex)
 
@@ -625,7 +628,9 @@ def _resolve_role_id(role, scope, definitions_client):
 
 
 def create_application(cmd, client, display_name, identifier_uris=None,
-                       is_fallback_public_client=None, sign_in_audience=None,
+                       is_fallback_public_client=None,
+                       service_management_reference=None,
+                       sign_in_audience=None,
                        # keyCredentials
                        key_value=None, key_type=None, key_usage=None, start_date=None, end_date=None,
                        key_display_name=None,
@@ -652,7 +657,9 @@ def create_application(cmd, client, display_name, identifier_uris=None,
                            existing_apps[0][ID])
             body = update_application(
                 existing_apps[0], display_name=display_name, identifier_uris=identifier_uris,
-                is_fallback_public_client=is_fallback_public_client, sign_in_audience=sign_in_audience,
+                is_fallback_public_client=is_fallback_public_client,
+                service_management_reference=service_management_reference,
+                sign_in_audience=sign_in_audience,
                 # keyCredentials
                 key_value=key_value, key_type=key_type, key_usage=key_usage,
                 start_date=start_date, end_date=end_date,
@@ -667,9 +674,9 @@ def create_application(cmd, client, display_name, identifier_uris=None,
                 app_roles=app_roles,
                 optional_claims=optional_claims,
                 required_resource_accesses=required_resource_accesses)
-            patch_application(cmd, existing_apps[0][ID], body)
 
-            # no need to resolve identifierUris or appId. Just use id.
+            # No need to resolve identifierUris or appId. Just use object id.
+            client.application_update(existing_apps[0][ID], body)
             return client.application_get(existing_apps[0][ID])
 
     # identifierUris is no longer required, compared to AD Graph
@@ -681,7 +688,9 @@ def create_application(cmd, client, display_name, identifier_uris=None,
 
     _set_application_properties(
         body, display_name=display_name, identifier_uris=identifier_uris,
-        is_fallback_public_client=is_fallback_public_client, sign_in_audience=sign_in_audience,
+        is_fallback_public_client=is_fallback_public_client,
+        service_management_reference=service_management_reference,
+        sign_in_audience=sign_in_audience,
         # keyCredentials
         key_credentials=key_credentials,
         # web
@@ -706,7 +715,9 @@ def create_application(cmd, client, display_name, identifier_uris=None,
 
 
 def update_application(instance, display_name=None, identifier_uris=None,  # pylint: disable=unused-argument
-                       is_fallback_public_client=None, sign_in_audience=None,
+                       is_fallback_public_client=None,
+                       service_management_reference=None,
+                       sign_in_audience=None,
                        # keyCredentials
                        key_value=None, key_type=None, key_usage=None, start_date=None, end_date=None,
                        key_display_name=None,
@@ -727,7 +738,9 @@ def update_application(instance, display_name=None, identifier_uris=None,  # pyl
 
     _set_application_properties(
         body, display_name=display_name, identifier_uris=identifier_uris,
-        is_fallback_public_client=is_fallback_public_client, sign_in_audience=sign_in_audience,
+        is_fallback_public_client=is_fallback_public_client,
+        service_management_reference=service_management_reference,
+        sign_in_audience=sign_in_audience,
         # keyCredentials
         key_credentials=key_credentials,
         # web
@@ -859,7 +872,7 @@ def _get_grant_permissions(client, client_sp_object_id=None, query_filter=None):
     try:
         # Make the REST request immediately so that errors can be raised and handled.
         return list(grant_info)
-    except CloudError as ex:
+    except HttpResponseError as ex:
         if ex.status_code == 404:
             raise CLIError("Service principal with appId or objectId '{id}' doesn't exist. "
                            "If '{id}' is an appId, make sure an associated service principal is created "
@@ -1157,7 +1170,7 @@ def list_service_principal_owners(client, identifier):
 def create_service_principal_for_rbac(
         # pylint:disable=too-many-statements,too-many-locals, too-many-branches, unused-argument
         cmd, display_name=None, years=None, create_cert=False, cert=None, scopes=None, role=None,
-        show_auth_for_sdk=None, skip_assignment=False, keyvault=None):
+        show_auth_in_json=None, skip_assignment=False, keyvault=None):
     import time
 
     if role and not scopes or not role and scopes:
@@ -1272,7 +1285,7 @@ def create_service_principal_for_rbac(
 
     logger.warning(CREDENTIAL_WARNING)
 
-    if show_auth_for_sdk:
+    if show_auth_in_json:
         from azure.cli.core._profile import Profile
         profile = Profile(cli_ctx=cmd.cli_ctx)
         result = profile.get_sp_auth_info(scopes[0].split('/')[2] if scopes else None,
@@ -1289,14 +1302,10 @@ def create_service_principal_for_rbac(
     }
     if cert_file:
         logger.warning(
-            "Please copy %s to a safe place. When you run 'az login', provide the file path in the --password argument",
+            "Please copy %s to a safe place. When you run `az login`, provide the file path in the --certificate "
+            "argument",
             cert_file)
         result['fileWithCertAndPrivateKey'] = cert_file
-
-    login_hint = ('To log in with this service principal, run:\n'
-                  f'az login --service-principal --username {app_id} --password {password or cert_file} '
-                  f'--tenant {graph_client.tenant}')
-    logger.info(login_hint)
     return result
 
 
@@ -1338,12 +1347,12 @@ def _process_certificate(cli_ctx, years, app_start_date, app_end_date, cert, cre
             _create_self_signed_cert_with_keyvault(cli_ctx, years, keyvault, cert)
     elif keyvault:
         # 6 - Use existing cert from KeyVault
-        kv_client = _get_keyvault_client(cli_ctx)
         vault_base = 'https://{}{}/'.format(keyvault, cli_ctx.cloud.suffixes.keyvault_dns)
-        cert_obj = kv_client.get_certificate(vault_base, cert, '')
+        kv_client = _get_keyvault_cert_client(cli_ctx, vault_base)
+        cert_obj = kv_client.get_certificate(cert)
         public_cert_string = base64.b64encode(cert_obj.cer).decode('utf-8')  # pylint: disable=no-member
-        cert_start_date = cert_obj.attributes.not_before  # pylint: disable=no-member
-        cert_end_date = cert_obj.attributes.expires  # pylint: disable=no-member
+        cert_start_date = cert_obj.properties.not_before  # pylint: disable=no-member
+        cert_end_date = cert_obj.properties.expires_on  # pylint: disable=no-member
 
     return public_cert_string, cert_file, cert_start_date, cert_end_date
 
@@ -1370,9 +1379,10 @@ def _validate_app_dates(app_start_date, app_end_date, cert_start_date, cert_end_
     return app_start_date, app_end_date, cert_start_date, cert_end_date
 
 
-def _get_keyvault_client(cli_ctx):
-    from azure.cli.command_modules.keyvault._client_factory import keyvault_data_plane_factory
-    return keyvault_data_plane_factory(cli_ctx)
+def _get_keyvault_cert_client(cli_ctx, vault_base_url):
+    from azure.cli.command_modules.keyvault._client_factory import data_plane_azure_keyvault_certificate_client
+    command_args = {'vault_base_url': vault_base_url}
+    return data_plane_azure_keyvault_certificate_client(cli_ctx, command_args=command_args)
 
 
 def _create_self_signed_cert(start_date, end_date):  # pylint: disable=too-many-locals
@@ -1429,9 +1439,9 @@ def _create_self_signed_cert(start_date, end_date):  # pylint: disable=too-many-
 
 
 def _create_self_signed_cert_with_keyvault(cli_ctx, years, keyvault, keyvault_cert_name):  # pylint: disable=too-many-locals
-    import time
-
-    kv_client = _get_keyvault_client(cli_ctx)
+    from azure.cli.command_modules.keyvault._validators import build_certificate_policy
+    vault_base_url = 'https://{}{}/'.format(keyvault, cli_ctx.cloud.suffixes.keyvault_dns)
+    kv_client = _get_keyvault_cert_client(cli_ctx, vault_base_url)
     cert_policy = {
         'issuer_parameters': {
             'name': 'Self'
@@ -1466,15 +1476,13 @@ def _create_self_signed_cert_with_keyvault(cli_ctx, years, keyvault, keyvault_ce
             'validity_in_months': int(years * 12)
         }
     }
-    vault_base_url = 'https://{}{}/'.format(keyvault, cli_ctx.cloud.suffixes.keyvault_dns)
-    kv_client.create_certificate(vault_base_url, keyvault_cert_name, cert_policy)
-    while kv_client.get_certificate_operation(vault_base_url, keyvault_cert_name).status != 'completed':  # pylint: disable=no-member, line-too-long
-        time.sleep(5)
+    policyObj = build_certificate_policy(cli_ctx, cert_policy)
+    kv_client.begin_create_certificate(keyvault_cert_name, policyObj).result()
 
-    cert = kv_client.get_certificate(vault_base_url, keyvault_cert_name, '')
+    cert = kv_client.get_certificate(keyvault_cert_name)
     cert_string = base64.b64encode(cert.cer).decode('utf-8')  # pylint: disable=no-member
-    cert_start_date = cert.attributes.not_before  # pylint: disable=no-member
-    cert_end_date = cert.attributes.expires  # pylint: disable=no-member
+    cert_start_date = cert.properties.not_before  # pylint: disable=no-member
+    cert_end_date = cert.properties.expires_on  # pylint: disable=no-member
     creds_file = None
     return (cert_string, creds_file, cert_start_date, cert_end_date)
 
@@ -1924,17 +1932,14 @@ def list_groups(client, display_name=None, query_filter=None):
 
 
 def get_group(client, object_id):
-    """Get group information from the directory."""
     return client.group_get(object_id)
 
 
 def delete_group(client, object_id):
-    """Delete a group from the directory."""
     return client.group_delete(object_id)
 
 
 def get_group_member_groups(client, object_id, security_enabled_only=False):
-    """Get a collection of object IDs of groups of which the specified group is a member."""
     return _get_member_groups(client.group_get_member_groups, object_id, security_enabled_only)
 
 
@@ -1963,12 +1968,10 @@ def check_group_membership(client, group_id, member_object_id):
 
 
 def list_group_members(client, group_id):
-    """Get the members of a group."""
     return client.group_member_list(group_id)
 
 
 def add_group_member(client, group_id, member_object_id):
-    """Add a member to a group."""
     # API is not idempotent and fails with:
     #   One or more added object references already exist for the following modified properties: 'members'.
     # TODO: make it idempotent like add_group_owner
@@ -1977,7 +1980,6 @@ def add_group_member(client, group_id, member_object_id):
 
 
 def remove_group_member(client, group_id, member_object_id):
-    """Remove a member from a group."""
     return client.group_member_remove(group_id, member_object_id)
 
 
