@@ -6,8 +6,7 @@
 from azure.cli.command_modules.vm._client_factory import (cf_vm, cf_avail_set,
                                                           cf_vm_ext, cf_vm_ext_image,
                                                           cf_vm_image, cf_vm_image_term, cf_usage,
-                                                          cf_vmss, cf_vmss_vm,
-                                                          cf_vm_sizes, cf_disks, cf_snapshots,
+                                                          cf_vmss, cf_disks, cf_snapshots,
                                                           cf_disk_accesses, cf_images, cf_run_commands,
                                                           cf_galleries, cf_gallery_images, cf_gallery_image_versions,
                                                           cf_proximity_placement_groups,
@@ -24,15 +23,18 @@ from azure.cli.command_modules.vm._client_factory import (cf_vm, cf_avail_set,
                                                           cf_community_gallery_image_version)
 from azure.cli.command_modules.vm._format import (
     transform_ip_addresses, transform_vm, transform_vm_create_output, transform_vm_usage_list, transform_vm_list,
-    transform_sku_for_table_output, transform_disk_show_table_output, transform_extension_show_table_output,
-    get_vmss_table_output_transformer, transform_vm_encryption_show_table_output, transform_log_analytics_query_output)
+    transform_disk_create_table_output, transform_sku_for_table_output, transform_disk_show_table_output,
+    transform_extension_show_table_output, get_vmss_table_output_transformer,
+    transform_vm_encryption_show_table_output, transform_log_analytics_query_output,
+    transform_vmss_list_with_zones_table_output, transform_vmss_list_without_zones_table_output)
 from azure.cli.command_modules.vm._validators import (
     process_vm_create_namespace, process_vmss_create_namespace, process_image_create_namespace,
     process_disk_create_namespace, process_snapshot_create_namespace,
     process_disk_encryption_namespace, process_assign_identity_namespace,
     process_remove_identity_namespace, process_vm_secret_format, process_vm_vmss_stop, validate_vmss_update_namespace,
     process_vm_update_namespace, process_set_applications_namespace, process_vm_disk_attach_namespace,
-    process_image_version_create_namespace, process_image_version_update_namespace, process_ppg_create_namespace)
+    process_image_version_create_namespace, process_image_version_update_namespace,
+    process_image_version_undelete_namespace, process_ppg_create_namespace, process_vm_disk_detach_namespace)
 
 from azure.cli.command_modules.vm._image_builder import (
     process_image_template_create_namespace, process_img_tmpl_output_add_namespace,
@@ -131,23 +133,12 @@ def load_command_table(self, _):
         client_factory=cf_vmss_run_commands
     )
 
-    compute_vm_size_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineSizesOperations.{}',
-        client_factory=cf_vm_sizes
-    )
-
     compute_vmss_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.compute.operations#VirtualMachineScaleSetsOperations.{}',
         client_factory=cf_vmss,
         operation_group='virtual_machine_scale_sets'
     )
 
-    compute_vmss_vm_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineScaleSetVMsOperations.{}',
-        client_factory=cf_vmss_vm,
-        operation_group='virtual_machine_scale_sets'
-    )
-
     compute_galleries_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.compute.operations#GalleriesOperations.{}',
         client_factory=cf_galleries,
@@ -247,22 +238,18 @@ def load_command_table(self, _):
         self.command_table["ppg show"] = PPGShow(loader=self)
 
     with self.command_group('disk', compute_disk_sdk, operation_group='disks', min_api='2017-03-30') as g:
-        g.custom_command('create', 'create_managed_disk', supports_no_wait=True, table_transformer=transform_disk_show_table_output, validator=process_disk_create_namespace)
-        g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
+        g.custom_command('create', 'create_managed_disk', supports_no_wait=True, table_transformer=transform_disk_create_table_output, validator=process_disk_create_namespace)
         g.custom_command('grant-access', 'grant_disk_access')
-        g.custom_command('list', 'list_managed_disks', table_transformer='[].' + transform_disk_show_table_output)
-        g.command('revoke-access', 'begin_revoke_access')
-        g.show_command('show', 'get', table_transformer=transform_disk_show_table_output)
         g.generic_update_command('update', custom_func_name='update_managed_disk', setter_name='begin_create_or_update', setter_arg_name='disk', supports_no_wait=True)
-        g.wait_command('wait')
+
+        from azure.cli.command_modules.vm._vm_utils import import_aaz_by_profile
+        Disk = import_aaz_by_profile(self.cli_ctx.cloud.profile, "disk")
+        self.command_table['disk list'] = Disk.List(loader=self, table_transformer='[].' + transform_disk_show_table_output)
+        self.command_table['disk show'] = Disk.Show(loader=self, table_transformer=transform_disk_show_table_output)
 
     with self.command_group('disk-encryption-set', compute_disk_encryption_set_sdk, operation_group='disk_encryption_sets', client_factory=cf_disk_encryption_set, min_api='2019-07-01') as g:
         g.custom_command('create', 'create_disk_encryption_set', supports_no_wait=True)
-        g.command('delete', 'begin_delete')
         g.generic_update_command('update', custom_func_name='update_disk_encryption_set', setter_arg_name='disk_encryption_set', setter_name='begin_create_or_update')
-        g.show_command('show', 'get')
-        g.custom_command('list', 'list_disk_encryption_sets')
-        g.command('list-associated-resources', 'list_associated_resources', min_api='2020-06-30')
 
     with self.command_group('disk-encryption-set identity', compute_disk_encryption_set_sdk, operation_group='disk_encryption_sets', client_factory=cf_disk_encryption_set, min_api='2022-03-02') as g:
         g.custom_command('assign', 'assign_disk_encryption_set_identity')
@@ -275,9 +262,6 @@ def load_command_table(self, _):
 
     with self.command_group('image', compute_image_sdk, min_api='2016-04-30-preview') as g:
         g.custom_command('create', 'create_image', validator=process_image_create_namespace)
-        g.custom_command('list', 'list_images')
-        g.show_command('show', 'get')
-        g.command('delete', 'begin_delete')
         g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_image')
 
     with self.command_group('image builder', image_builder_image_templates_sdk, custom_command_type=image_builder_custom) as g:
@@ -322,15 +306,15 @@ def load_command_table(self, _):
         g.custom_command('remove', 'remove_template_optimizer', supports_local_cache=True)
         g.custom_show_command('show', 'show_template_optimizer', supports_local_cache=True)
 
+    with self.command_group('image builder error-handler', image_builder_image_templates_sdk, custom_command_type=image_builder_custom) as g:
+        g.custom_command('add', 'add_template_error_handler', supports_local_cache=True)
+        g.custom_command('remove', 'remove_template_error_handler', supports_local_cache=True)
+        g.custom_show_command('show', 'show_template_error_handler', supports_local_cache=True)
+
     with self.command_group('snapshot', compute_snapshot_sdk, operation_group='snapshots', min_api='2016-04-30-preview') as g:
         g.custom_command('create', 'create_snapshot', validator=process_snapshot_create_namespace, supports_no_wait=True)
-        g.command('delete', 'begin_delete')
         g.custom_command('grant-access', 'grant_snapshot_access')
-        g.custom_command('list', 'list_snapshots')
-        g.command('revoke-access', 'begin_revoke_access')
-        g.show_command('show', 'get')
         g.generic_update_command('update', custom_func_name='update_snapshot', setter_name='begin_create_or_update', setter_arg_name='snapshot', supports_no_wait=True)
-        g.wait_command('wait')
 
     with self.command_group('vm', compute_vm_sdk) as g:
         g.custom_command('identity assign', 'assign_vm_identity', validator=process_assign_identity_namespace)
@@ -342,31 +326,20 @@ def load_command_table(self, _):
 
         g.custom_command('capture', 'capture_vm')
         g.custom_command('create', 'create_vm', transform=transform_vm_create_output, supports_no_wait=True, table_transformer=deployment_validate_table_format, validator=process_vm_create_namespace, exception_handler=handle_template_based_exception)
-        g.command('convert', 'begin_convert_to_managed_disks', min_api='2016-04-30-preview')
-        g.command('deallocate', 'begin_deallocate', supports_no_wait=True)
         g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
-        g.command('generalize', 'generalize', supports_no_wait=True)
         g.custom_command('get-instance-view', 'get_instance_view', table_transformer='{Name:name, ResourceGroup:resourceGroup, Location:location, ProvisioningState:provisioningState, PowerState:instanceView.statuses[1].displayStatus}')
         g.custom_command('list', 'list_vm', table_transformer=transform_vm_list)
         g.custom_command('list-ip-addresses', 'list_vm_ip_addresses', table_transformer=transform_ip_addresses)
-        g.command('list-sizes', 'list', command_type=compute_vm_size_sdk)
         g.custom_command('list-skus', 'list_skus', table_transformer=transform_sku_for_table_output, min_api='2017-03-30')
         g.command('list-usage', 'list', command_type=compute_vm_usage_sdk, transform=transform_vm_usage_list, table_transformer='[].{Name:localName, CurrentValue:currentValue, Limit:limit}')
-        g.command('list-vm-resize-options', 'list_available_sizes')
         g.custom_command('open-port', 'open_vm_port')
-        g.command('perform-maintenance', 'begin_perform_maintenance', min_api='2017-03-30')
-        g.command('redeploy', 'begin_redeploy', supports_no_wait=True)
         g.custom_command('resize', 'resize_vm', supports_no_wait=True)
         g.custom_command('restart', 'restart_vm', supports_no_wait=True)
         g.custom_show_command('show', 'show_vm', table_transformer=transform_vm)
-        g.command('simulate-eviction', 'simulate_eviction', min_api='2019-12-01')
-        g.command('start', 'begin_start', supports_no_wait=True)
         g.command('stop', 'begin_power_off', supports_no_wait=True, validator=process_vm_vmss_stop)
-        g.command('reapply', 'begin_reapply', supports_no_wait=True, min_api='2019-07-01')
         g.generic_update_command('update', getter_name='get_vm_to_update', setter_name='update_vm', setter_type=compute_custom, command_type=compute_custom, supports_no_wait=True, validator=process_vm_update_namespace)
         g.wait_command('wait', getter_name='get_instance_view', getter_type=compute_custom)
         g.custom_command('auto-shutdown', 'auto_shutdown_vm')
-        g.command('assess-patches', 'begin_assess_patches', min_api='2020-06-01')
 
     with self.command_group('vm', compute_vm_sdk, client_factory=cf_vm) as g:
         g.custom_command('install-patches', 'install_vm_patches', supports_no_wait=True, min_api='2020-12-01')
@@ -374,10 +347,7 @@ def load_command_table(self, _):
     with self.command_group('vm availability-set', compute_availset_sdk) as g:
         g.custom_command('convert', 'convert_av_set_to_managed_disk', min_api='2016-04-30-preview')
         g.custom_command('create', 'create_av_set', table_transformer=deployment_validate_table_format, supports_no_wait=True, exception_handler=handle_template_based_exception)
-        g.command('delete', 'delete')
         g.custom_command('list', 'list_av_sets')
-        g.command('list-sizes', 'list_available_sizes')
-        g.show_command('show', 'get')
         g.generic_update_command('update', custom_func_name='update_av_set')
 
     with self.command_group('vm boot-diagnostics', compute_vm_sdk) as g:
@@ -392,7 +362,7 @@ def load_command_table(self, _):
 
     with self.command_group('vm disk', compute_vm_sdk, min_api='2017-03-30') as g:
         g.custom_command('attach', 'attach_managed_data_disk', validator=process_vm_disk_attach_namespace)
-        g.custom_command('detach', 'detach_managed_data_disk')
+        g.custom_command('detach', 'detach_managed_data_disk', validator=process_vm_disk_detach_namespace)
 
     with self.command_group('vm encryption', custom_command_type=compute_disk_encryption_custom) as g:
         g.custom_command('enable', 'encrypt_vm', validator=process_disk_encryption_namespace)
@@ -474,28 +444,34 @@ def load_command_table(self, _):
         g.custom_command('application list', 'list_vmss_applications', min_api='2021-07-01')
         g.custom_command('create', 'create_vmss', transform=DeploymentOutputLongRunningOperation(self.cli_ctx, 'Starting vmss create'), supports_no_wait=True, table_transformer=deployment_validate_table_format, validator=process_vmss_create_namespace, exception_handler=handle_template_based_exception)
         g.custom_command('deallocate', 'deallocate_vmss', supports_no_wait=True)
-        g.command('delete', 'begin_delete', supports_no_wait=True)
         g.custom_command('delete-instances', 'delete_vmss_instances', supports_no_wait=True)
         g.custom_command('get-instance-view', 'get_vmss_instance_view', table_transformer='{ProvisioningState:statuses[0].displayStatus, PowerState:statuses[1].displayStatus}')
-        g.custom_command('list', 'list_vmss', table_transformer=get_vmss_table_output_transformer(self))
-        g.command('list-instances', 'list', command_type=compute_vmss_vm_sdk)
         g.custom_command('list-instance-connection-info', 'list_vmss_instance_connection_info')
         g.custom_command('list-instance-public-ips', 'list_vmss_instance_public_ips')
-        g.command('list-skus', 'list_skus')
         g.custom_command('reimage', 'reimage_vmss', supports_no_wait=True, min_api='2017-03-30')
-        g.command('perform-maintenance', 'begin_perform_maintenance', min_api='2017-12-01')
         g.custom_command('restart', 'restart_vmss', supports_no_wait=True)
         g.custom_command('scale', 'scale_vmss', supports_no_wait=True)
         g.custom_show_command('show', 'get_vmss', table_transformer=get_vmss_table_output_transformer(self, False))
-        g.command('simulate-eviction', 'simulate_eviction', command_type=compute_vmss_vm_sdk, min_api='2019-12-01')
         g.custom_command('start', 'start_vmss', supports_no_wait=True)
         g.custom_command('stop', 'stop_vmss', supports_no_wait=True, validator=process_vm_vmss_stop)
         g.generic_update_command('update', getter_name='get_vmss_modified', setter_name='update_vmss', supports_no_wait=True, command_type=compute_custom, validator=validate_vmss_update_namespace)
         g.custom_command('update-instances', 'update_vmss_instances', supports_no_wait=True)
         g.wait_command('wait', getter_name='get_vmss', getter_type=compute_custom)
-        g.command('get-os-upgrade-history', 'get_os_upgrade_history', min_api='2018-10-01')
         g.custom_command('set-orchestration-service-state', 'set_orchestration_service_state', supports_no_wait=True)
 
+        from azure.cli.command_modules.vm._vm_utils import import_aaz_by_profile
+        VMSS = import_aaz_by_profile(self.cli_ctx.cloud.profile, "vmss")
+        if self.supported_api_version(min_api='2017-03-30'):
+            self.command_table['vmss list'] = VMSS.List(loader=self,
+                                                        table_transformer=transform_vmss_list_with_zones_table_output)
+        else:
+            self.command_table['vmss list'] = VMSS.List(loader=self,
+                                                        table_transformer=transform_vmss_list_without_zones_table_output)
+
+        if self.cli_ctx.cloud.profile == 'latest':
+            from .custom import VMSSListInstances
+            self.command_table['vmss list-instances'] = VMSSListInstances(loader=self)
+
     with self.command_group('vmss diagnostics', compute_vmss_sdk) as g:
         g.custom_command('set', 'set_vmss_diagnostics_extension')
         g.custom_command('get-default-config', 'show_default_diagnostics_configuration')
@@ -540,7 +516,6 @@ def load_command_table(self, _):
         g.custom_command('list-community', 'sig_community_image_definition_list')
 
     with self.command_group('sig image-version', community_gallery_image_version_sdk, client_factory=cf_community_gallery_image_version, operation_group='shared_galleries', min_api='2022-01-03') as g:
-        g.command('show-community', 'get')
         g.custom_command('list-community', 'sig_community_image_version_list')
 
     with self.command_group('sig image-definition', compute_gallery_images_sdk, operation_group='gallery_images', min_api='2018-06-01') as g:
@@ -548,10 +523,9 @@ def load_command_table(self, _):
         g.generic_update_command('update', setter_name='begin_create_or_update', setter_arg_name='gallery_image')
 
     with self.command_group('sig image-version', compute_gallery_image_versions_sdk, operation_group='gallery_image_versions', min_api='2018-06-01') as g:
-        g.command('delete', 'begin_delete')
         g.show_command('show', 'get', table_transformer='{Name:name, ResourceGroup:resourceGroup, ProvisioningState:provisioningState, TargetRegions: publishingProfile.targetRegions && join(`, `, publishingProfile.targetRegions[*].name), EdgeZones: publishingProfile.targetExtendedLocations && join(`, `, publishingProfile.targetExtendedLocations[*].name), ReplicationState:replicationStatus.aggregatedState}')
-        g.command('list', 'list_by_gallery_image')
         g.custom_command('create', 'create_image_version', supports_no_wait=True, validator=process_image_version_create_namespace)
+        g.custom_command('undelete', 'undelete_image_version', supports_no_wait=True, min_api='2021-07-01', validator=process_image_version_undelete_namespace, is_preview=True)
         g.generic_update_command('update', getter_name='get_image_version_to_update', setter_arg_name='gallery_image_version', setter_name='update_image_version', setter_type=compute_custom, command_type=compute_custom, supports_no_wait=True, validator=process_image_version_update_namespace)
         g.wait_command('wait')
 
@@ -591,15 +565,13 @@ def load_command_table(self, _):
         g.custom_command('list-shared', 'sig_shared_image_definition_list')
 
     vm_shared_gallery_image_version = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations._shared_gallery_image_versions_operations#SharedGalleryImageVers'
-        'ionsOperations.{}',
+        operations_tmpl='azure.mgmt.compute.operations#SharedGalleryImageVersionsOperations.{}',
         client_factory=cf_shared_gallery_image_version,
         operation_group='shared_galleries')
     with self.command_group('sig image-version', vm_shared_gallery_image_version, min_api='2020-09-30',
                             operation_group='shared_galleries',
                             client_factory=cf_shared_gallery_image_version) as g:
         g.custom_command('list-shared', 'sig_shared_image_version_list')
-        g.command('show-shared', 'get')
 
     with self.command_group('sig gallery-application', compute_gallery_application_sdk, client_factory=cf_gallery_application, min_api='2021-07-01', operation_group='gallery_applications') as g:
         g.custom_command('create', 'gallery_application_create', supports_no_wait=True)
@@ -628,14 +600,17 @@ def load_command_table(self, _):
             pass
 
     with self.command_group('capacity reservation group', capacity_reservation_groups_sdk, min_api='2021-04-01',
-                            client_factory=cf_capacity_reservation_groups, is_preview=True) as g:
+                            client_factory=cf_capacity_reservation_groups) as g:
         g.custom_command('create', 'create_capacity_reservation_group')
         g.custom_command('update', 'update_capacity_reservation_group')
         g.custom_show_command('show', 'show_capacity_reservation_group')
-        g.custom_command('list', 'list_capacity_reservation_group')
+
+    with self.command_group('capacity reservation group'):
+        from .custom import CapacityReservationGroupList
+        self.command_table['capacity reservation group list'] = CapacityReservationGroupList(loader=self)
 
     with self.command_group('capacity reservation', capacity_reservations_sdk, min_api='2021-04-01',
-                            client_factory=cf_capacity_reservations, is_preview=True) as g:
+                            client_factory=cf_capacity_reservations) as g:
         g.custom_command('create', 'create_capacity_reservation', supports_no_wait=True)
         g.custom_command('update', 'update_capacity_reservation', supports_no_wait=True)
         g.custom_show_command('show', 'show_capacity_reservation')
